#!/bin/bash
gmt gmtset PS_MEDIA letter
gmt gmtset PROJ_LENGTH_UNIT cm
gmt gmtset FORMAT_GEO_MAP D
gmt gmtset PS_PAGE_ORIENTATION portrait
psfile=altai1.21_base.ps
projection=-JM16.0c+
region=-R86.6/89.7/49.2/51.0
gmt psbasemap $region $projection -Bxa1.0f0.1 -Bya1.0f0.1 -BWeSn+t'Base Map altai1.21' -K > $psfile

# Standard Topography (ETOPO1)
palette=-Ctables/gmt/cpt/topo.cpt
gmt grdcut @earth_relief_01m_g -Gmloc.grd $region
gmt grdgradient mloc.grd -Gmloc_ilum.grd -A340 -Nt
gmt grdimage mloc.grd $palette $projection -Imloc_ilum.grd -O -K >> $psfile
rm mloc.grd mloc_ilum.grd

# Coastlines and rivers
gmt pscoast $projection $region -Df -Ia/blue -Wblue -O -K >> $psfile

# Event numbers
gmt psxy -: -R $projection -Sl8p+t"1" -G0 -O -K << END >> $psfile
    50.329    87.685
END
gmt psxy -: -R $projection -Sl8p+t"2" -G0 -O -K << END >> $psfile
    50.297    87.633
END
gmt psxy -: -R $projection -Sl8p+t"3" -G0 -O -K << END >> $psfile
    50.238    87.842
END
gmt psxy -: -R $projection -Sl8p+t"4" -G0 -O -K << END >> $psfile
    50.019    87.568
END
gmt psxy -: -R $projection -Sl8p+t"5" -G0 -O -K << END >> $psfile
    50.229    88.508
END
gmt psxy -: -R $projection -Sl8p+t"6" -G0 -O -K << END >> $psfile
    50.025    87.858
END
gmt psxy -: -R $projection -Sl8p+t"7" -G0 -O -K << END >> $psfile
    49.938    88.146
END
gmt psxy -: -R $projection -Sl8p+t"8" -G0 -O -K << END >> $psfile
    50.049    87.888
END
gmt psxy -: -R $projection -Sl8p+t"9" -G0 -O -K << END >> $psfile
    50.048    87.873
END
gmt psxy -: -R $projection -Sl8p+t"10" -G0 -O -K << END >> $psfile
    50.082    87.878
END
gmt psxy -: -R $projection -Sl8p+t"11" -G0 -O -K << END >> $psfile
    49.909    88.136
END
gmt psxy -: -R $projection -Sl8p+t"12" -G0 -O -K << END >> $psfile
    50.099    87.769
END
gmt psxy -: -R $projection -Sl8p+t"13" -G0 -O -K << END >> $psfile
    50.045    87.851
END
gmt psxy -: -R $projection -Sl8p+t"14" -G0 -O -K << END >> $psfile
    50.011    87.958
END
gmt psxy -: -R $projection -Sl8p+t"15" -G0 -O -K << END >> $psfile
    49.900    88.144
END
gmt psxy -: -R $projection -Sl8p+t"16" -G0 -O -K << END >> $psfile
    50.078    87.793
END
gmt psxy -: -R $projection -Sl8p+t"17" -G0 -O -K << END >> $psfile
    49.985    88.203
END
gmt psxy -: -R $projection -Sl8p+t"18" -G0 -O -K << END >> $psfile
    49.941    88.123
END
gmt psxy -: -R $projection -Sl8p+t"19" -G0 -O -K << END >> $psfile
    50.032    87.660
END
gmt psxy -: -R $projection -Sl8p+t"20" -G0 -O -K << END >> $psfile
    50.007    87.889
END
gmt psxy -: -R $projection -Sl8p+t"21" -G0 -O -K << END >> $psfile
    50.047    87.819
END
gmt psxy -: -R $projection -Sl8p+t"22" -G0 -O -K << END >> $psfile
    49.953    87.983
END
gmt psxy -: -R $projection -Sl8p+t"23" -G0 -O -K << END >> $psfile
    50.163    87.734
END
gmt psxy -: -R $projection -Sl8p+t"24" -G0 -O -K << END >> $psfile
    49.981    87.818
END
gmt psxy -: -R $projection -Sl8p+t"25" -G0 -O -K << END >> $psfile
    49.991    88.176
END
gmt psxy -: -R $projection -Sl8p+t"26" -G0 -O -K << END >> $psfile
    50.219    87.779
END
gmt psxy -: -R $projection -Sl8p+t"27" -G0 -O -K << END >> $psfile
    50.001    87.855
END
gmt psxy -: -R $projection -Sl8p+t"28" -G0 -O -K << END >> $psfile
    50.147    87.722
END
gmt psxy -: -R $projection -Sl8p+t"29" -G0 -O -K << END >> $psfile
    50.182    87.627
END
gmt psxy -: -R $projection -Sl8p+t"30" -G0 -O -K << END >> $psfile
    50.218    87.634
END
gmt psxy -: -R $projection -Sl8p+t"31" -G0 -O -K << END >> $psfile
    50.153    87.831
END
gmt psxy -: -R $projection -Sl8p+t"32" -G0 -O -K << END >> $psfile
    49.986    87.775
END
gmt psxy -: -R $projection -Sl8p+t"33" -G0 -O -K << END >> $psfile
    50.182    87.650
END
gmt psxy -: -R $projection -Sl8p+t"34" -G0 -O -K << END >> $psfile
    50.176    87.679
END
gmt psxy -: -R $projection -Sl8p+t"35" -G0 -O -K << END >> $psfile
    50.147    87.734
END
gmt psxy -: -R $projection -Sl8p+t"36" -G0 -O -K << END >> $psfile
    50.086    87.776
END
gmt psxy -: -R $projection -Sl8p+t"37" -G0 -O -K << END >> $psfile
    50.157    87.742
END
gmt psxy -: -R $projection -Sl8p+t"38" -G0 -O -K << END >> $psfile
    50.001    87.887
END
gmt psxy -: -R $projection -Sl8p+t"39" -G0 -O -K << END >> $psfile
    49.906    88.223
END
gmt psxy -: -R $projection -Sl8p+t"40" -G0 -O -K << END >> $psfile
    49.901    88.129
END
gmt psxy -: -R $projection -Sl8p+t"41" -G0 -O -K << END >> $psfile
    50.210    87.674
END
gmt psxy -: -R $projection -Sl8p+t"42" -G0 -O -K << END >> $psfile
    50.130    87.804
END
gmt psxy -: -R $projection -Sl8p+t"43" -G0 -O -K << END >> $psfile
    49.926    88.182
END
gmt psxy -: -R $projection -Sl8p+t"44" -G0 -O -K << END >> $psfile
    50.176    87.541
END
gmt psxy -: -R $projection -Sl8p+t"45" -G0 -O -K << END >> $psfile
    50.201    87.649
END
gmt psxy -: -R $projection -Sl8p+t"46" -G0 -O -K << END >> $psfile
    49.776    87.944
END
gmt psxy -: -R $projection -Sl8p+t"47" -G0 -O -K << END >> $psfile
    50.160    87.832
END
gmt psxy -: -R $projection -Sl8p+t"48" -G0 -O -K << END >> $psfile
    49.999    87.913
END
gmt psxy -: -R $projection -Sl8p+t"49" -G0 -O -K << END >> $psfile
    49.815    87.977
END
gmt psxy -: -R $projection -Sl8p+t"50" -G0 -O -K << END >> $psfile
    50.140    87.752
END
gmt psxy -: -R $projection -Sl8p+t"51" -G0 -O -K << END >> $psfile
    49.929    88.097
END
gmt psxy -: -R $projection -Sl8p+t"52" -G0 -O -K << END >> $psfile
    50.216    87.562
END
gmt psxy -: -R $projection -Sl8p+t"53" -G0 -O -K << END >> $psfile
    50.111    87.910
END
gmt psxy -: -R $projection -Sl8p+t"54" -G0 -O -K << END >> $psfile
    50.038    87.843
END
gmt psxy -: -R $projection -Sl8p+t"55" -G0 -O -K << END >> $psfile
    49.823    88.288
END
gmt psxy -: -R $projection -Sl8p+t"56" -G0 -O -K << END >> $psfile
    49.867    87.904
END
gmt psxy -: -R $projection -Sl8p+t"57" -G0 -O -K << END >> $psfile
    50.196    87.602
END
gmt psxy -: -R $projection -Sl8p+t"58" -G0 -O -K << END >> $psfile
    50.201    87.572
END
gmt psxy -: -R $projection -Sl8p+t"59" -G0 -O -K << END >> $psfile
    50.127    87.791
END
gmt psxy -: -R $projection -Sl8p+t"60" -G0 -O -K << END >> $psfile
    50.270    87.512
END
gmt psxy -: -R $projection -Sl8p+t"61" -G0 -O -K << END >> $psfile
    49.959    88.084
END
gmt psxy -: -R $projection -Sl8p+t"62" -G0 -O -K << END >> $psfile
    50.230    87.511
END
gmt psxy -: -R $projection -Sl8p+t"63" -G0 -O -K << END >> $psfile
    50.120    87.814
END
gmt psxy -: -R $projection -Sl8p+t"64" -G0 -O -K << END >> $psfile
    50.009    88.085
END
gmt psxy -: -R $projection -Sl8p+t"65" -G0 -O -K << END >> $psfile
    50.018    87.866
END
gmt psxy -: -R $projection -Sl8p+t"66" -G0 -O -K << END >> $psfile
    50.237    87.500
END
gmt psxy -: -R $projection -Sl8p+t"67" -G0 -O -K << END >> $psfile
    50.291    87.475
END
gmt psxy -: -R $projection -Sl8p+t"68" -G0 -O -K << END >> $psfile
    50.058    87.872
END
gmt psxy -: -R $projection -Sl8p+t"69" -G0 -O -K << END >> $psfile
    50.141    87.792
END
gmt psxy -: -R $projection -Sl8p+t"70" -G0 -O -K << END >> $psfile
    50.229    87.576
END
gmt psxy -: -R $projection -Sl8p+t"71" -G0 -O -K << END >> $psfile
    49.973    87.885
END
gmt psxy -: -R $projection -Sl8p+t"72" -G0 -O -K << END >> $psfile
    50.181    87.697
END
gmt psxy -: -R $projection -Sl8p+t"73" -G0 -O -K << END >> $psfile
    50.024    87.902
END
gmt psxy -: -R $projection -Sl8p+t"74" -G0 -O -K << END >> $psfile
    50.186    87.728
END
gmt psxy -: -R $projection -Sl8p+t"75" -G0 -O -K << END >> $psfile
    50.221    87.576
END
gmt psxy -: -R $projection -Sl8p+t"76" -G0 -O -K << END >> $psfile
    50.035    87.901
END
gmt psxy -: -R $projection -Sl8p+t"77" -G0 -O -K << END >> $psfile
    50.241    87.645
END
gmt psxy -: -R $projection -Sl8p+t"78" -G0 -O -K << END >> $psfile
    50.197    87.599
END
gmt psxy -: -R $projection -Sl8p+t"79" -G0 -O -K << END >> $psfile
    50.216    87.514
END
gmt psxy -: -R $projection -Sl8p+t"80" -G0 -O -K << END >> $psfile
    49.832    88.240
END
gmt psxy -: -R $projection -Sl8p+t"81" -G0 -O -K << END >> $psfile
    50.211    87.544
END
gmt psxy -: -R $projection -Sl8p+t"82" -G0 -O -K << END >> $psfile
    50.028    87.867
END
gmt psxy -: -R $projection -Sl8p+t"83" -G0 -O -K << END >> $psfile
    50.156    87.658
END
gmt psxy -: -R $projection -Sl8p+t"84" -G0 -O -K << END >> $psfile
    49.936    88.096
END
gmt psxy -: -R $projection -Sl8p+t"85" -G0 -O -K << END >> $psfile
    50.225    87.644
END
gmt psxy -: -R $projection -Sl8p+t"86" -G0 -O -K << END >> $psfile
    49.919    88.260
END
gmt psxy -: -R $projection -Sl8p+t"87" -G0 -O -K << END >> $psfile
    49.905    88.127
END
gmt psxy -: -R $projection -Sl8p+t"88" -G0 -O -K << END >> $psfile
    49.865    88.289
END
gmt psxy -: -R $projection -Sl8p+t"89" -G0 -O -K << END >> $psfile
    50.235    87.717
END
gmt psxy -: -R $projection -Sl8p+t"90" -G0 -O -K << END >> $psfile
    50.090    87.782
END
gmt psxy -: -R $projection -Sl8p+t"91" -G0 -O -K << END >> $psfile
    49.987    87.903
END
gmt psxy -: -R $projection -Sl8p+t"92" -G0 -O -K << END >> $psfile
    49.836    88.232
END
gmt psxy -: -R $projection -Sl8p+t"93" -G0 -O -K << END >> $psfile
    50.031    87.856
END
gmt psxy -: -R $projection -Sl8p+t"94" -G0 -O -K << END >> $psfile
    49.863    88.272
END
gmt psxy -: -R $projection -Sl8p+t"95" -G0 -O -K << END >> $psfile
    50.290    87.488
END
gmt psxy -: -R $projection -Sl8p+t"96" -G0 -O -K << END >> $psfile
    50.167    87.717
END
gmt psxy -: -R $projection -Sl8p+t"97" -G0 -O -K << END >> $psfile
    49.822    88.206
END
gmt psxy -: -R $projection -Sl8p+t"98" -G0 -O -K << END >> $psfile
    49.932    88.273
END
gmt psxy -: -R $projection -Sl8p+t"99" -G0 -O -K << END >> $psfile
    50.149    87.768
END
gmt psxy -: -R $projection -Sl8p+t"100" -G0 -O -K << END >> $psfile
    50.043    87.991
END
gmt psxy -: -R $projection -Sl8p+t"101" -G0 -O -K << END >> $psfile
    49.873    88.165
END
gmt psxy -: -R $projection -Sl8p+t"102" -G0 -O -K << END >> $psfile
    49.876    88.262
END
gmt psxy -: -R $projection -Sl8p+t"103" -G0 -O -K << END >> $psfile
    50.033    87.884
END
gmt psxy -: -R $projection -Sl8p+t"104" -G0 -O -K << END >> $psfile
    49.919    87.924
END
gmt psxy -: -R $projection -Sl8p+t"105" -G0 -O -K << END >> $psfile
    50.261    87.504
END
gmt psxy -: -R $projection -Sl8p+t"106" -G0 -O -K << END >> $psfile
    50.259    87.568
END
gmt psxy -: -R $projection -Sl8p+t"107" -G0 -O -K << END >> $psfile
    49.885    87.721
END
gmt psxy -: -R $projection -Sl8p+t"108" -G0 -O -K << END >> $psfile
    50.139    87.909
END
gmt psxy -: -R $projection -Sl8p+t"109" -G0 -O -K << END >> $psfile
    49.671    87.418
END
gmt psxy -: -R $projection -Sl8p+t"110" -G0 -O -K << END >> $psfile
    50.126    87.862
END
gmt psxy -: -R $projection -Sl8p+t"111" -G0 -O -K << END >> $psfile
    50.069    87.859
END
gmt psxy -: -R $projection -Sl8p+t"112" -G0 -O -K << END >> $psfile
    50.123    87.905
END
gmt psxy -: -R $projection -Sl8p+t"113" -G0 -O -K << END >> $psfile
    50.182    87.649
END
gmt psxy -: -R $projection -Sl8p+t"114" -G0 -O -K << END >> $psfile
    50.174    87.731
END
gmt psxy -: -R $projection -Sl8p+t"115" -G0 -O -K << END >> $psfile
    50.022    87.707
END
gmt psxy -: -R $projection -Sl8p+t"116" -G0 -O -K << END >> $psfile
    50.101    87.636
END
gmt psxy -: -R $projection -Sl8p+t"117" -G0 -O -K << END >> $psfile
    49.907    88.127
END
gmt psxy -: -R $projection -Sl8p+t"118" -G0 -O -K << END >> $psfile
    49.921    88.058
END
gmt psxy -: -R $projection -Sl8p+t"119" -G0 -O -K << END >> $psfile
    50.008    87.889
END
gmt psxy -: -R $projection -Sl8p+t"120" -G0 -O -K << END >> $psfile
    49.922    88.093
END
gmt psxy -: -R $projection -Sl8p+t"121" -G0 -O -K << END >> $psfile
    50.109    87.733
END
gmt psxy -: -R $projection -Sl8p+t"122" -G0 -O -K << END >> $psfile
    49.927    88.264
END
gmt psxy -: -R $projection -Sl8p+t"123" -G0 -O -K << END >> $psfile
    50.136    87.863
END
gmt psxy -: -R $projection -Sl8p+t"124" -G0 -O -K << END >> $psfile
    49.863    88.135
END
gmt psxy -: -R $projection -Sl8p+t"125" -G0 -O -K << END >> $psfile
    49.861    88.202
END
gmt psxy -: -R $projection -Sl8p+t"126" -G0 -O -K << END >> $psfile
    49.816    87.846
END
gmt psxy -: -R $projection -Sl8p+t"127" -G0 -O -K << END >> $psfile
    49.942    88.020
END
gmt psxy -: -R $projection -Sl8p+t"128" -G0 -O -K << END >> $psfile
    50.320    87.456
END
gmt psxy -: -R $projection -Sl8p+t"129" -G0 -O -K << END >> $psfile
    49.848    88.269
END
gmt psxy -: -R $projection -Sl8p+t"130" -G0 -O -K << END >> $psfile
    49.960    87.944
END
gmt psxy -: -R $projection -Sl8p+t"131" -G0 -O -K << END >> $psfile
    49.717    87.717
END
gmt psxy -: -R $projection -Sl8p+t"132" -G0 -O -K << END >> $psfile
    50.154    87.278
END
gmt psxy -: -R $projection -Sl8p+t"133" -G0 -O -K << END >> $psfile
    49.943    89.019
END
gmt psxy -: -R $projection -Sl8p+t"134" -G0 -O -K << END >> $psfile
    50.206    87.508
END
gmt psxy -: -R $projection -Sl8p+t"135" -G0 -O -K << END >> $psfile
    49.847    88.277
END
gmt psxy -: -R $projection -Sl8p+t"136" -G0 -O -K << END >> $psfile
    49.970    87.845
END
gmt psxy -: -R $projection -Sl8p+t"137" -G0 -O -K << END >> $psfile
    50.259    87.520
END
gmt psxy -: -R $projection -Sl8p+t"138" -G0 -O -K << END >> $psfile
    49.707    87.765
END
gmt psxy -: -R $projection -Sl8p+t"139" -G0 -O -K << END >> $psfile
    49.926    88.223
END
gmt psxy -: -R $projection -Sl8p+t"140" -G0 -O -K << END >> $psfile
    50.184    87.625
END
gmt psxy -: -R $projection -Sl8p+t"141" -G0 -O -K << END >> $psfile
    50.084    87.865
END
gmt psxy -: -R $projection -Sl8p+t"142" -G0 -O -K << END >> $psfile
    50.029    87.814
END
gmt psxy -: -R $projection -Sl8p+t"143" -G0 -O -K << END >> $psfile
    50.036    87.549
END
gmt psxy -: -R $projection -Sl8p+t"144" -G0 -O -K << END >> $psfile
    50.002    88.032
END
gmt psxy -: -R $projection -Sl8p+t"145" -G0 -O -K << END >> $psfile
    50.049    87.622
END
gmt psxy -: -R $projection -Sl8p+t"146" -G0 -O -K << END >> $psfile
    49.896    88.336
END
gmt psxy -: -R $projection -Sl8p+t"147" -G0 -O -K << END >> $psfile
    49.902    87.654
END
gmt psxy -: -R $projection -Sl8p+t"148" -G0 -O -K << END >> $psfile
    50.126    87.515
END
gmt psxy -: -R $projection -Sl8p+t"149" -G0 -O -K << END >> $psfile
    49.852    88.280
END
gmt psxy -: -R $projection -Sl8p+t"150" -G0 -O -K << END >> $psfile
    50.274    87.526
END
gmt psxy -: -R $projection -Sl8p+t"151" -G0 -O -K << END >> $psfile
    50.284    87.536
END
gmt psxy -: -R $projection -Sl8p+t"152" -G0 -O -K << END >> $psfile
    50.281    87.514
END
gmt psxy -: -R $projection -Sl8p+t"153" -G0 -O -K << END >> $psfile
    49.859    88.181
END
gmt psxy -: -R $projection -Sl8p+t"154" -G0 -O -K << END >> $psfile
    50.286    87.527
END
gmt psxy -: -R $projection -Sl8p+t"155" -G0 -O -K << END >> $psfile
    49.723    87.989
END
gmt psxy -: -R $projection -Sl8p+t"156" -G0 -O -K << END >> $psfile
    50.050    87.780
END
gmt psxy -: -R $projection -Sl8p+t"157" -G0 -O -K << END >> $psfile
    50.094    87.846
END
gmt psxy -: -R $projection -Sl8p+t"158" -G0 -O -K << END >> $psfile
    50.054    87.545
END
gmt psxy -: -R $projection -Sl8p+t"159" -G0 -O -K << END >> $psfile
    50.067    87.896
END
gmt psxy -: -R $projection -Sl8p+t"160" -G0 -O -K << END >> $psfile
    49.994    88.387
END
gmt psxy -: -R $projection -Sl8p+t"161" -G0 -O -K << END >> $psfile
    49.939    88.272
END
gmt psxy -: -R $projection -Sl8p+t"162" -G0 -O -K << END >> $psfile
    49.861    88.243
END
gmt psxy -: -R $projection -Sl8p+t"163" -G0 -O -K << END >> $psfile
    50.131    87.792
END
gmt psxy -: -R $projection -Sl8p+t"164" -G0 -O -K << END >> $psfile
    50.162    87.470
END
gmt psxy -: -R $projection -Sl8p+t"165" -G0 -O -K << END >> $psfile
    49.973    88.016
END
gmt psxy -: -R $projection -Sl8p+t"166" -G0 -O -K << END >> $psfile
    50.134    87.512
END
gmt psxy -: -R $projection -Sl8p+t"167" -G0 -O -K << END >> $psfile
    50.224    87.715
END
gmt psxy -: -R $projection -Sl8p+t"168" -G0 -O -K << END >> $psfile
    50.039    87.568
END
gmt psxy -: -R $projection -Sl8p+t"169" -G0 -O -K << END >> $psfile
    50.052    87.905
END
gmt psxy -: -R $projection -Sl8p+t"170" -G0 -O -K << END >> $psfile
    50.035    87.967
END
gmt psxy -: -R $projection -Sl8p+t"171" -G0 -O -K << END >> $psfile
    49.849    87.964
END
gmt psxy -: -R $projection -Sl8p+t"172" -G0 -O -K << END >> $psfile
    49.928    88.084
END
gmt psxy -: -R $projection -Sl8p+t"173" -G0 -O -K << END >> $psfile
    49.700    87.821
END
gmt psxy -: -R $projection -Sl8p+t"174" -G0 -O -K << END >> $psfile
    49.975    87.944
END
gmt psxy -: -R $projection -Sl8p+t"175" -G0 -O -K << END >> $psfile
    50.571    87.142
END
gmt psxy -: -R $projection -Sl8p+t"176" -G0 -O -K << END >> $psfile
    50.093    87.913
END
gmt psxy -: -R $projection -Sl8p+t"177" -G0 -O -K << END >> $psfile
    49.857    88.081
END
gmt psxy -: -R $projection -Sl8p+t"178" -G0 -O -K << END >> $psfile
    49.877    87.849
END
gmt psxy -: -R $projection -Sl8p+t"179" -G0 -O -K << END >> $psfile
    50.043    87.868
END
gmt psxy -: -R $projection -Sl8p+t"180" -G0 -O -K << END >> $psfile
    49.821    88.233
END
gmt psxy -: -R $projection -Sl8p+t"181" -G0 -O -K << END >> $psfile
    50.185    87.664
END
gmt psxy -: -R $projection -Sl8p+t"182" -G0 -O -K << END >> $psfile
    50.294    87.513
END
gmt psxy -: -R $projection -Sl8p+t"183" -G0 -O -K << END >> $psfile
    50.551    87.321
END
gmt psxy -: -R $projection -Sl8p+t"184" -G0 -O -K << END >> $psfile
    49.985    87.898
END
gmt psxy -: -R $projection -Sl8p+t"185" -G0 -O -K << END >> $psfile
    50.301    88.292
END
gmt psxy -: -R $projection -Sl8p+t"186" -G0 -O -K << END >> $psfile
    50.533    87.402
END
gmt psxy -: -R $projection -Sl8p+t"187" -G0 -O -K << END >> $psfile
    50.343    87.469
END
gmt psxy -: -R $projection -Sl8p+t"188" -G0 -O -K << END >> $psfile
    50.039    87.887
END
gmt psxy -: -R $projection -Sl8p+t"189" -G0 -O -K << END >> $psfile
    50.018    87.504
END
gmt psxy -: -R $projection -Sl8p+t"190" -G0 -O -K << END >> $psfile
    50.752    86.929
END
gmt psxy -: -R $projection -Sl8p+t"191" -G0 -O -K << END >> $psfile
    50.108    87.484
END
gmt psxy -: -R $projection -Sl8p+t"192" -G0 -O -K << END >> $psfile
    49.878    87.126
END
gmt psxy -: -R $projection -Sl8p+t"193" -G0 -O -K << END >> $psfile
    49.869    88.312
END
gmt psxy -: -R $projection -Sl8p+t"194" -G0 -O -K << END >> $psfile
    50.156    88.641
END
gmt psxy -: -R $projection -Sl8p+t"195" -G0 -O -K << END >> $psfile
    50.257    87.519
END
gmt psxy -: -R $projection -Sl8p+t"196" -G0 -O -K << END >> $psfile
    50.132    87.825
END
gmt psxy -: -R $projection -Sl8p+t"197" -G0 -O -K << END >> $psfile
    50.295    87.611
END
gmt psxy -: -R $projection -Sl8p+t"198" -G0 -O -K << END >> $psfile
    49.992    87.379
END
gmt psxy -: -R $projection -Sl8p+t"199" -G0 -O -K << END >> $psfile
    49.830    88.272
END
gmt psxy -: -R $projection -Sl8p+t"200" -G0 -O -K << END >> $psfile
    49.835    88.311
END
gmt psxy -: -R $projection -Sl8p+t"201" -G0 -O -K << END >> $psfile
    50.149    87.617
END
gmt psxy -: -R $projection -Sl8p+t"202" -G0 -O -K << END >> $psfile
    49.961    88.849
END
gmt psxy -: -R $projection -Sl8p+t"203" -G0 -O -K << END >> $psfile
    50.151    87.711
END
gmt psxy -: -R $projection -Sl8p+t"204" -G0 -O -K << END >> $psfile
    50.558    87.340
END
gmt psxy -: -R $projection -Sl8p+t"205" -G0 -O -K << END >> $psfile
    49.994    87.349
END
gmt psxy -: -R $projection -Sl8p+t"206" -G0 -O -K << END >> $psfile
    50.132    87.795
END
gmt psxy -: -R $projection -Sl8p+t"207" -G0 -O -K << END >> $psfile
    50.219    87.547
END
gmt psxy -: -R $projection -Sl8p+t"208" -G0 -O -K << END >> $psfile
    50.345    87.719
END
gmt psxy -: -R $projection -Sl8p+t"209" -G0 -O -K << END >> $psfile
    49.793    88.218
END
gmt psxy -: -R $projection -Sl8p+t"210" -G0 -O -K << END >> $psfile
    50.032    87.688
END
gmt psxy -: -R $projection -Sl8p+t"211" -G0 -O -K << END >> $psfile
    50.253    87.582
END
gmt psxy -: -R $projection -Sl8p+t"212" -G0 -O -K << END >> $psfile
    50.144    87.763
END
gmt psxy -: -R $projection -Sl8p+t"213" -G0 -O -K << END >> $psfile
    50.184    87.783
END
gmt psxy -: -R $projection -Sl8p+t"214" -G0 -O -K << END >> $psfile
    50.051    87.542
END
gmt psxy -: -R $projection -Sl8p+t"215" -G0 -O -K << END >> $psfile
    50.699    87.116
END
gmt psxy -: -R $projection -Sl8p+t"216" -G0 -O -K << END >> $psfile
    50.249    87.472
END
gmt psxy -: -R $projection -Sl8p+t"217" -G0 -O -K << END >> $psfile
    50.236    87.597
END
gmt psxy -: -R $projection -Sl8p+t"218" -G0 -O -K << END >> $psfile
    49.854    88.289
END
gmt psxy -: -R $projection -Sl8p+t"219" -G0 -O -K << END >> $psfile
    49.727    87.870
END
gmt psxy -: -R $projection -Sl8p+t"220" -G0 -O -K << END >> $psfile
    50.111    87.898
END
gmt psxy -: -R $projection -Sl8p+t"221" -G0 -O -K << END >> $psfile
    50.587    87.330
END
gmt psxy -: -R $projection -Sl8p+t"222" -G0 -O -K << END >> $psfile
    50.002    87.957
END
gmt psxy -: -R $projection -Sl8p+t"223" -G0 -O -K << END >> $psfile
    50.550    87.292
END
gmt psxy -: -R $projection -Sl8p+t"224" -G0 -O -K << END >> $psfile
    49.834    88.275
END
gmt psxy -: -R $projection -Sl8p+t"225" -G0 -O -K << END >> $psfile
    49.769    87.648
END
gmt psxy -: -R $projection -Sl8p+t"226" -G0 -O -K << END >> $psfile
    49.793    87.581
END
gmt psxy -: -R $projection -Sl8p+t"227" -G0 -O -K << END >> $psfile
    49.767    87.753
END
gmt psxy -: -R $projection -Sl8p+t"228" -G0 -O -K << END >> $psfile
    50.018    87.897
END
gmt psxy -: -R $projection -Sl8p+t"229" -G0 -O -K << END >> $psfile
    50.210    87.484
END
gmt psxy -: -R $projection -Sl8p+t"230" -G0 -O -K << END >> $psfile
    49.822    88.169
END
gmt psxy -: -R $projection -Sl8p+t"231" -G0 -O -K << END >> $psfile
    50.128    87.885
END
gmt psxy -: -R $projection -Sl8p+t"232" -G0 -O -K << END >> $psfile
    50.577    87.300
END
gmt psxy -: -R $projection -Sl8p+t"233" -G0 -O -K << END >> $psfile
    50.077    87.839
END
gmt psxy -: -R $projection -Sl8p+t"234" -G0 -O -K << END >> $psfile
    50.881    88.591
END
gmt psxy -: -R $projection -Sl8p+t"235" -G0 -O -K << END >> $psfile
    50.148    88.599
END
gmt psxy -: -R $projection -Sl8p+t"236" -G0 -O -K << END >> $psfile
    50.179    87.682
END
gmt psxy -: -R $projection -Sl8p+t"237" -G0 -O -K << END >> $psfile
    50.611    87.419
END
gmt psxy -: -R $projection -Sl8p+t"238" -G0 -O -K << END >> $psfile
    50.297    87.939
END
gmt psxy -: -R $projection -Sl8p+t"239" -G0 -O -K << END >> $psfile
    49.992    87.914
END
gmt psxy -: -R $projection -Sl8p+t"240" -G0 -O -K << END >> $psfile
    49.906    87.712
END
gmt psxy -: -R $projection -Sl8p+t"241" -G0 -O -K << END >> $psfile
    49.896    88.052
END
gmt psxy -: -R $projection -Sl8p+t"242" -G0 -O -K << END >> $psfile
    50.038    87.925
END
gmt psxy -: -R $projection -Sl8p+t"243" -G0 -O -K << END >> $psfile
    49.819    88.217
END
gmt psxy -: -R $projection -Sl8p+t"244" -G0 -O -K << END >> $psfile
    50.137    87.730
END
gmt psxy -: -R $projection -Sl8p+t"245" -G0 -O -K << END >> $psfile
    49.903    88.223
END
gmt psxy -: -R $projection -Sl8p+t"246" -G0 -O -K << END >> $psfile
    50.222    87.591
END
gmt psxy -: -R $projection -Sl8p+t"247" -G0 -O -K << END >> $psfile
    49.850    87.919
END
gmt psxy -: -R $projection -Sl8p+t"248" -G0 -O -K << END >> $psfile
    49.953    87.928
END
gmt psxy -: -R $projection -Sl8p+t"249" -G0 -O -K << END >> $psfile
    50.045    87.888
END
gmt psxy -: -R $projection -Sl8p+t"250" -G0 -O -K << END >> $psfile
    50.314    87.525
END
gmt psxy -: -R $projection -Sl8p+t"251" -G0 -O -K << END >> $psfile
    49.828    88.195
END
gmt psxy -: -R $projection -Sl8p+t"252" -G0 -O -K << END >> $psfile
    50.118    87.734
END
gmt psxy -: -R $projection -Sl8p+t"253" -G0 -O -K << END >> $psfile
    50.119    87.722
END
gmt psxy -: -R $projection -Sl8p+t"254" -G0 -O -K << END >> $psfile
    50.138    87.652
END
gmt psxy -: -R $projection -Sl8p+t"255" -G0 -O -K << END >> $psfile
    49.798    87.716
END
gmt psxy -: -R $projection -Sl8p+t"256" -G0 -O -K << END >> $psfile
    50.020    87.425
END
gmt psxy -: -R $projection -Sl8p+t"257" -G0 -O -K << END >> $psfile
    50.064    87.814
END
gmt psxy -: -R $projection -Sl8p+t"258" -G0 -O -K << END >> $psfile
    49.819    87.377
END
gmt psxy -: -R $projection -Sl8p+t"259" -G0 -O -K << END >> $psfile
    49.793    87.965
END
gmt psxy -: -R $projection -Sl8p+t"260" -G0 -O -K << END >> $psfile
    50.116    87.755
END
gmt psxy -: -R $projection -Sl8p+t"261" -G0 -O -K << END >> $psfile
    50.493    87.430
END
gmt psxy -: -R $projection -Sl8p+t"262" -G0 -O -K << END >> $psfile
    49.254    86.743
END
gmt psxy -: -R $projection -Sl8p+t"263" -G0 -O -K << END >> $psfile
    50.565    87.342
END
gmt psxy -: -R $projection -Sl8p+t"264" -G0 -O -K << END >> $psfile
    50.042    88.394
END
gmt psxy -: -R $projection -Sl8p+t"265" -G0 -O -K << END >> $psfile
    50.011    87.664
END
gmt psxy -: -R $projection -Sl8p+t"266" -G0 -O -K << END >> $psfile
    49.883    88.109
END
gmt psxy -: -R $projection -Sl8p+t"267" -G0 -O -K << END >> $psfile
    50.136    87.668
END
gmt psxy -: -R $projection -Sl8p+t"268" -G0 -O -K << END >> $psfile
    49.755    87.703
END
gmt psxy -: -R $projection -Sl8p+t"269" -G0 -O -K << END >> $psfile
    50.305    88.067
END
gmt psxy -: -R $projection -Sl8p+t"270" -G0 -O -K << END >> $psfile
    49.870    87.072
END
gmt psxy -: -R $projection -Sl8p+t"271" -G0 -O -K << END >> $psfile
    49.344    88.433
END
gmt psxy -: -R $projection -Sl8p+t"272" -G0 -O -K << END >> $psfile
    50.204    87.927
END
gmt psxy -: -R $projection -Sl8p+t"273" -G0 -O -K << END >> $psfile
    50.121    87.711
END
gmt psxy -: -R $projection -Sl8p+t"274" -G0 -O -K << END >> $psfile
    49.831    87.656
END
gmt psxy -: -R $projection -Sl8p+t"275" -G0 -O -K << END >> $psfile
    49.800    87.658
END
gmt psxy -: -R $projection -Sl8p+t"276" -G0 -O -K << END >> $psfile
    49.801    87.732
END
gmt psxy -: -R $projection -Sl8p+t"277" -G0 -O -K << END >> $psfile
    50.162    87.718
END
gmt psxy -: -R $projection -Sl8p+t"278" -G0 -O -K << END >> $psfile
    50.025    87.885
END
gmt psxy -: -R $projection -Sl8p+t"279" -G0 -O -K << END >> $psfile
    50.168    87.690
END
gmt psxy -: -R $projection -Sl8p+t"280" -G0 -O -K << END >> $psfile
    49.959    88.006
END
gmt psxy -: -R $projection -Sl8p+t"281" -G0 -O -K << END >> $psfile
    50.093    87.865
END
gmt psxy -: -R $projection -Sl8p+t"282" -G0 -O -K << END >> $psfile
    50.583    87.341
END
gmt psxy -: -R $projection -Sl8p+t"283" -G0 -O -K << END >> $psfile
    50.536    87.450
END
gmt psxy -: -R $projection -Sl8p+t"284" -G0 -O -K << END >> $psfile
    50.071    87.896
END
gmt psxy -: -R $projection -Sl8p+t"285" -G0 -O -K << END >> $psfile
    50.104    88.814
END
gmt psxy -: -R $projection -Sl8p+t"286" -G0 -O -K << END >> $psfile
    50.129    87.783
END
gmt psxy -: -R $projection -Sl8p+t"287" -G0 -O -K << END >> $psfile
    49.994    87.907
END
gmt psxy -: -R $projection -Sl8p+t"288" -G0 -O -K << END >> $psfile
    50.213    88.508
END
gmt psxy -: -R $projection -Sl8p+t"289" -G0 -O -K << END >> $psfile
    50.477    87.460
END
gmt psxy -: -R $projection -Sl8p+t"290" -G0 -O -K << END >> $psfile
    49.809    87.895
END
gmt psxy -: -R $projection -Sl8p+t"291" -G0 -O -K << END >> $psfile
    50.118    87.768
END
gmt psxy -: -R $projection -Sl8p+t"292" -G0 -O -K << END >> $psfile
    50.686    88.281
END
gmt psxy -: -R $projection -Sl8p+t"293" -G0 -O -K << END >> $psfile
    50.125    88.138
END
gmt psxy -: -R $projection -Sl8p+t"294" -G0 -O -K << END >> $psfile
    50.467    87.434
END
gmt psxy -: -R $projection -Sl8p+t"295" -G0 -O -K << END >> $psfile
    50.205    87.580
END
gmt psxy -: -R $projection -Sl8p+t"296" -G0 -O -K << END >> $psfile
    49.990    88.074
END
gmt psxy -: -R $projection -Sl8p+t"297" -G0 -O -K << END >> $psfile
    50.134    87.822
END
gmt psxy -: -R $projection -Sl8p+t"298" -G0 -O -K << END >> $psfile
    50.012    87.497
END
gmt psxy -: -R $projection -Sl8p+t"299" -G0 -O -K << END >> $psfile
    50.256    87.586
END
gmt psxy -: -R $projection -Sl8p+t"300" -G0 -O -K << END >> $psfile
    49.989    87.751
END
gmt psxy -: -R $projection -Sl8p+t"301" -G0 -O -K << END >> $psfile
    49.875    88.100
END
gmt psxy -: -R $projection -Sl8p+t"302" -G0 -O -K << END >> $psfile
    49.844    88.088
END
gmt psxy -: -R $projection -Sl8p+t"303" -G0 -O -K << END >> $psfile
    50.209    87.617
END
gmt psxy -: -R $projection -Sl8p+t"304" -G0 -O -K << END >> $psfile
    50.514    87.378
END
gmt psxy -: -R $projection -Sl8p+t"305" -G0 -O -K << END >> $psfile
    50.204    87.622
END
gmt psxy -: -R $projection -Sl8p+t"306" -G0 -O -K << END >> $psfile
    50.001    87.933
END
gmt psxy -: -R $projection -Sl8p+t"307" -G0 -O -K << END >> $psfile
    50.006    87.908
END
gmt psxy -: -R $projection -Sl8p+t"308" -G0 -O -K << END >> $psfile
    50.288    88.121
END
gmt psxy -: -R $projection -Sl8p+t"309" -G0 -O -K << END >> $psfile
    50.170    88.615
END
gmt psxy -: -R $projection -Sl8p+t"310" -G0 -O -K << END >> $psfile
    49.590    87.359
END
gmt psxy -: -R $projection -Sl8p+t"311" -G0 -O -K << END >> $psfile
    50.075    87.743
END
gmt psxy -: -R $projection -Sl8p+t"312" -G0 -O -K << END >> $psfile
    50.284    87.917
END
gmt psxy -: -R $projection -Sl8p+t"313" -G0 -O -K << END >> $psfile
    50.300    87.876
END
gmt psxy -: -R $projection -Sl8p+t"314" -G0 -O -K << END >> $psfile
    50.110    87.601
END
gmt psxy -: -R $projection -Sl8p+t"315" -G0 -O -K << END >> $psfile
    50.263    87.783
END
gmt psxy -: -R $projection -Sl8p+t"316" -G0 -O -K << END >> $psfile
    49.810    88.105
END
gmt psxy -: -R $projection -Sl8p+t"317" -G0 -O -K << END >> $psfile
    50.091    87.787
END
gmt psxy -: -R $projection -Sl8p+t"318" -G0 -O -K << END >> $psfile
    49.883    88.021
END
gmt psxy -: -R $projection -Sl8p+t"319" -G0 -O -K << END >> $psfile
    50.478    87.479
END
gmt psxy -: -R $projection -Sl8p+t"320" -G0 -O -K << END >> $psfile
    50.040    87.786
END
gmt psxy -: -R $projection -Sl8p+t"321" -G0 -O -K << END >> $psfile
    49.845    88.162
END
gmt psxy -: -R $projection -Sl8p+t"322" -G0 -O -K << END >> $psfile
    49.786    86.792
END
gmt psxy -: -R $projection -Sl8p+t"323" -G0 -O -K << END >> $psfile
    50.061    87.716
END
gmt psxy -: -R $projection -Sl8p+t"324" -G0 -O -K << END >> $psfile
    50.147    87.790
END
gmt psxy -: -R $projection -Sl8p+t"325" -G0 -O -K << END >> $psfile
    50.105    87.825
END
gmt psxy -: -R $projection -Sl8p+t"326" -G0 -O -K << END >> $psfile
    50.023    87.983
END
gmt psxy -: -R $projection -Sl8p+t"327" -G0 -O -K << END >> $psfile
    49.994    88.831
END
gmt psxy -: -R $projection -Sl8p+t"328" -G0 -O -K << END >> $psfile
    50.164    87.774
END
gmt psxy -: -R $projection -Sl8p+t"329" -G0 -O -K << END >> $psfile
    50.251    88.281
END
gmt psxy -: -R $projection -Sl8p+t"330" -G0 -O -K << END >> $psfile
    50.077    87.896
END
gmt psxy -: -R $projection -Sl8p+t"331" -G0 -O -K << END >> $psfile
    49.856    88.796
END
gmt psxy -: -R $projection -Sl8p+t"332" -G0 -O -K << END >> $psfile
    50.017    87.878
END
gmt psxy -: -R $projection -Sl8p+t"333" -G0 -O -K << END >> $psfile
    50.013    87.880
END
gmt psxy -: -R $projection -Sl8p+t"334" -G0 -O -K << END >> $psfile
    50.018    87.876
END
gmt psxy -: -R $projection -Sl8p+t"335" -G0 -O -K << END >> $psfile
    50.158    87.671
END
gmt psxy -: -R $projection -Sl8p+t"336" -G0 -O -K << END >> $psfile
    49.838    88.260
END
gmt psxy -: -R $projection -Sl8p+t"337" -G0 -O -K << END >> $psfile
    49.993    88.849
END
gmt psxy -: -R $projection -Sl8p+t"338" -G0 -O -K << END >> $psfile
    50.514    87.387
END
gmt psxy -: -R $projection -Sl8p+t"339" -G0 -O -K << END >> $psfile
    50.073    87.813
END
gmt psxy -: -R $projection -Sl8p+t"340" -G0 -O -K << END >> $psfile
    49.854    88.149
END
gmt psxy -: -R $projection -Sl8p+t"341" -G0 -O -K << END >> $psfile
    50.326    87.794
END
gmt psxy -: -R $projection -Sl8p+t"342" -G0 -O -K << END >> $psfile
    50.869    86.711
END
gmt psxy -: -R $projection -Sl8p+t"343" -G0 -O -K << END >> $psfile
    50.124    87.789
END
gmt psxy -: -R $projection -Sl8p+t"344" -G0 -O -K << END >> $psfile
    50.200    87.922
END
gmt psxy -: -R $projection -Sl8p+t"345" -G0 -O -K << END >> $psfile
    50.068    87.733
END
gmt psxy -: -R $projection -Sl8p+t"346" -G0 -O -K << END >> $psfile
    49.817    88.218
END
gmt psxy -: -R $projection -Sl8p+t"347" -G0 -O -K << END >> $psfile
    50.699    88.334
END
gmt psxy -: -R $projection -Sl8p+t"348" -G0 -O -K << END >> $psfile
    49.904    88.100
END
gmt psxy -: -R $projection -Sl8p+t"349" -G0 -O -K << END >> $psfile
    50.018    87.619
END
gmt psxy -: -R $projection -Sl8p+t"350" -G0 -O -K << END >> $psfile
    49.973    88.130
END
gmt psxy -: -R $projection -Sl8p+t"351" -G0 -O -K << END >> $psfile
    50.590    87.336
END
gmt psxy -: -R $projection -Sl8p+t"352" -G0 -O -K << END >> $psfile
    49.723    87.095
END
gmt psxy -: -R $projection -Sl8p+t"353" -G0 -O -K << END >> $psfile
    50.002    87.883
END
gmt psxy -: -R $projection -Sl8p+t"354" -G0 -O -K << END >> $psfile
    49.843    87.792
END
gmt psxy -: -R $projection -Sl8p+t"355" -G0 -O -K << END >> $psfile
    49.920    88.187
END
gmt psxy -: -R $projection -Sl8p+t"356" -G0 -O -K << END >> $psfile
    50.543    87.426
END
gmt psxy -: -R $projection -Sl8p+t"357" -G0 -O -K << END >> $psfile
    50.100    87.429
END
gmt psxy -: -R $projection -Sl8p+t"358" -G0 -O -K << END >> $psfile
    49.914    88.163
END
gmt psxy -: -R $projection -Sl8p+t"359" -G0 -O -K << END >> $psfile
    50.551    87.417
END
gmt psxy -: -R $projection -Sl8p+t"360" -G0 -O -K << END >> $psfile
    50.531    87.439
END
gmt psxy -: -R $projection -Sl8p+t"361" -G0 -O -K << END >> $psfile
    50.537    87.413
END
gmt psxy -: -R $projection -Sl8p+t"362" -G0 -O -K << END >> $psfile
    50.509    87.465
END
gmt psxy -: -R $projection -Sl8p+t"363" -G0 -O -K << END >> $psfile
    50.537    87.426
END
gmt psxy -: -R $projection -Sl8p+t"364" -G0 -O -K << END >> $psfile
    50.526    87.467
END
gmt psxy -: -R $projection -Sl8p+t"365" -G0 -O -K << END >> $psfile
    50.538    87.460
END
gmt psxy -: -R $projection -Sl8p+t"366" -G0 -O -K << END >> $psfile
    50.529    87.438
END
gmt psxy -: -R $projection -Sl8p+t"367" -G0 -O -K << END >> $psfile
    49.837    88.193
END
gmt psxy -: -R $projection -Sl8p+t"368" -G0 -O -K << END >> $psfile
    50.536    87.434
END
gmt psxy -: -R $projection -Sl8p+t"369" -G0 -O -K << END >> $psfile
    50.528    87.440
END
gmt psxy -: -R $projection -Sl8p+t"370" -G0 -O -K << END >> $psfile
    50.516    87.477
END
gmt psxy -: -R $projection -Sl8p+t"371" -G0 -O -K << END >> $psfile
    50.537    87.433
END
gmt psxy -: -R $projection -Sl8p+t"372" -G0 -O -K << END >> $psfile
    50.504    87.460
END
gmt psxy -: -R $projection -Sl8p+t"373" -G0 -O -K << END >> $psfile
    49.880    88.117
END
gmt psxy -: -R $projection -Sl8p+t"374" -G0 -O -K << END >> $psfile
    50.545    87.427
END
gmt psxy -: -R $projection -Sl8p+t"375" -G0 -O -K << END >> $psfile
    49.927    88.134
END
gmt psxy -: -R $projection -Sl8p+t"376" -G0 -O -K << END >> $psfile
    50.542    87.445
END
gmt psxy -: -R $projection -Sl8p+t"377" -G0 -O -K << END >> $psfile
    50.540    87.454
END
gmt psxy -: -R $projection -Sl8p+t"378" -G0 -O -K << END >> $psfile
    50.537    87.464
END
gmt psxy -: -R $projection -Sl8p+t"379" -G0 -O -K << END >> $psfile
    50.145    87.901
END
gmt psxy -: -R $projection -Sl8p+t"380" -G0 -O -K << END >> $psfile
    50.046    88.475
END
gmt psxy -: -R $projection -Sl8p+t"381" -G0 -O -K << END >> $psfile
    50.445    87.285
END
gmt psxy -: -R $projection -Sl8p+t"382" -G0 -O -K << END >> $psfile
    50.556    87.434
END
gmt psxy -: -R $projection -Sl8p+t"383" -G0 -O -K << END >> $psfile
    50.053    88.395
END
gmt psxy -: -R $projection -Sl8p+t"384" -G0 -O -K << END >> $psfile
    50.531    87.412
END
gmt psxy -: -R $projection -Sl8p+t"385" -G0 -O -K << END >> $psfile
    50.526    87.423
END
gmt psxy -: -R $projection -Sl8p+t"386" -G0 -O -K << END >> $psfile
    50.534    87.405
END
gmt psxy -: -R $projection -Sl8p+t"387" -G0 -O -K << END >> $psfile
    50.519    87.433
END
gmt psxy -: -R $projection -Sl8p+t"388" -G0 -O -K << END >> $psfile
    50.892    86.981
END
gmt psxy -: -R $projection -Sl8p+t"389" -G0 -O -K << END >> $psfile
    50.515    87.438
END
gmt psxy -: -R $projection -Sl8p+t"390" -G0 -O -K << END >> $psfile
    50.537    87.454
END
gmt psxy -: -R $projection -Sl8p+t"391" -G0 -O -K << END >> $psfile
    50.527    87.421
END
gmt psxy -: -R $projection -Sl8p+t"392" -G0 -O -K << END >> $psfile
    50.533    87.418
END
gmt psxy -: -R $projection -Sl8p+t"393" -G0 -O -K << END >> $psfile
    50.171    87.663
END
gmt psxy -: -R $projection -Sl8p+t"394" -G0 -O -K << END >> $psfile
    49.798    86.818
END
gmt psxy -: -R $projection -Sl8p+t"395" -G0 -O -K << END >> $psfile
    50.699    88.299
END
gmt psxy -: -R $projection -Sl8p+t"396" -G0 -O -K << END >> $psfile
    50.098    87.695
END
gmt psxy -: -R $projection -Sl8p+t"397" -G0 -O -K << END >> $psfile
    49.801    86.808
END
gmt psxy -: -R $projection -Sl8p+t"398" -G0 -O -K << END >> $psfile
    49.702    87.438
END
gmt psxy -: -R $projection -Sl8p+t"399" -G0 -O -K << END >> $psfile
    50.012    87.902
END
gmt psxy -: -R $projection -Sl8p+t"400" -G0 -O -K << END >> $psfile
    50.140    87.656
END
gmt psxy -: -R $projection -Sl8p+t"401" -G0 -O -K << END >> $psfile
    49.254    88.135
END
gmt psxy -: -R $projection -Sl8p+t"402" -G0 -O -K << END >> $psfile
    50.556    87.432
END
gmt psxy -: -R $projection -Sl8p+t"403" -G0 -O -K << END >> $psfile
    50.044    87.892
END
gmt psxy -: -R $projection -Sl8p+t"404" -G0 -O -K << END >> $psfile
    50.047    87.898
END
gmt psxy -: -R $projection -Sl8p+t"405" -G0 -O -K << END >> $psfile
    50.046    87.894
END
gmt psxy -: -R $projection -Sl8p+t"406" -G0 -O -K << END >> $psfile
    50.209    87.859
END
gmt psxy -: -R $projection -Sl8p+t"407" -G0 -O -K << END >> $psfile
    49.824    88.490
END
gmt psxy -: -R $projection -Sl8p+t"408" -G0 -O -K << END >> $psfile
    50.025    87.607
END
gmt psxy -: -R $projection -Sl8p+t"409" -G0 -O -K << END >> $psfile
    49.850    88.157
END
gmt psxy -: -R $projection -Sl8p+t"410" -G0 -O -K << END >> $psfile
    49.845    88.223
END
gmt psxy -: -R $projection -Sl8p+t"411" -G0 -O -K << END >> $psfile
    50.520    87.450
END
gmt psxy -: -R $projection -Sl8p+t"412" -G0 -O -K << END >> $psfile
    50.010    88.383
END
gmt psxy -: -R $projection -Sl8p+t"413" -G0 -O -K << END >> $psfile
    50.339    87.857
END
gmt psxy -: -R $projection -Sl8p+t"414" -G0 -O -K << END >> $psfile
    50.081    87.768
END
gmt psxy -: -R $projection -Sl8p+t"415" -G0 -O -K << END >> $psfile
    50.568    87.364
END
gmt psxy -: -R $projection -Sl8p+t"416" -G0 -O -K << END >> $psfile
    50.134    87.802
END
gmt psxy -: -R $projection -Sl8p+t"417" -G0 -O -K << END >> $psfile
    50.186    87.559
END
gmt psxy -: -R $projection -Sl8p+t"418" -G0 -O -K << END >> $psfile
    50.033    87.888
END
gmt psxy -: -R $projection -Sl8p+t"419" -G0 -O -K << END >> $psfile
    50.045    87.891
END
gmt psxy -: -R $projection -Sl8p+t"420" -G0 -O -K << END >> $psfile
    49.708    89.573
END
gmt psxy -: -R $projection -Sl8p+t"421" -G0 -O -K << END >> $psfile
    50.039    87.902
END
gmt psxy -: -R $projection -Sl8p+t"422" -G0 -O -K << END >> $psfile
    49.957    88.763
END
gmt psxy -: -R $projection -Sl8p+t"423" -G0 -O -K << END >> $psfile
    50.682    87.227
END
gmt psxy -: -R $projection -Sl8p+t"424" -G0 -O -K << END >> $psfile
    49.543    87.787
END
gmt psxy -: -R $projection -Sl8p+t"425" -G0 -O -K << END >> $psfile
    49.648    89.095
END

# Change in location, calibration shift if available
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.327    87.679
    50.329    87.685
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.380    87.700
    50.329    87.685
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.300    87.636
    50.297    87.633
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.330    87.670
    50.297    87.633
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.243    87.853
    50.238    87.842
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.190    87.870
    50.238    87.842
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.019    87.569
    50.019    87.568
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.011    87.461
    50.019    87.568
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.230    88.508
    50.229    88.508
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.239    88.588
    50.229    88.508
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.024    87.857
    50.025    87.858
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.973    87.759
    50.025    87.858
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.938    88.146
    49.938    88.146
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.005    88.052
    49.938    88.146
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.051    87.890
    50.049    87.888
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.073    87.852
    50.049    87.888
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.048    87.874
    50.048    87.873
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.139    87.829
    50.048    87.873
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.082    87.880
    50.082    87.878
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.083    87.837
    50.082    87.878
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.909    88.138
    49.909    88.136
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.972    88.106
    49.909    88.136
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.100    87.770
    50.099    87.769
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.089    87.786
    50.099    87.769
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.047    87.852
    50.045    87.851
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.014    87.784
    50.045    87.851
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.010    87.960
    50.011    87.958
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.148    87.931
    50.011    87.958
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.901    88.143
    49.900    88.144
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.985    88.063
    49.900    88.144
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.078    87.795
    50.078    87.793
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.139    87.828
    50.078    87.793
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.984    88.204
    49.985    88.203
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.024    88.091
    49.985    88.203
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.941    88.124
    49.941    88.123
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.063    88.140
    49.941    88.123
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.033    87.657
    50.032    87.660
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.067    87.645
    50.032    87.660
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.007    87.892
    50.007    87.889
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.990    87.726
    50.007    87.889
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.046    87.818
    50.047    87.819
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.090    87.579
    50.047    87.819
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.953    87.984
    49.953    87.983
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.044    88.030
    49.953    87.983
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.163    87.736
    50.163    87.734
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.206    87.734
    50.163    87.734
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.981    87.818
    49.981    87.818
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.154    87.680
    49.981    87.818
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.990    88.177
    49.991    88.176
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.064    88.142
    49.991    88.176
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.219    87.780
    50.219    87.779
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.283    87.771
    50.219    87.779
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.999    87.854
    50.001    87.855
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.056    87.707
    50.001    87.855
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.148    87.722
    50.147    87.722
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.141    87.607
    50.147    87.722
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.182    87.625
    50.182    87.627
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.229    87.606
    50.182    87.627
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.218    87.634
    50.218    87.634
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.231    87.363
    50.218    87.634
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.154    87.832
    50.153    87.831
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.325    87.797
    50.153    87.831
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.985    87.771
    49.986    87.775
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.120    87.612
    49.986    87.775
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.182    87.650
    50.182    87.650
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.166    87.572
    50.182    87.650
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.176    87.678
    50.176    87.679
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.993    87.441
    50.176    87.679
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.146    87.736
    50.147    87.734
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.206    87.336
    50.147    87.734
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.086    87.775
    50.086    87.776
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.933    87.604
    50.086    87.776
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.157    87.744
    50.157    87.742
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.136    87.491
    50.157    87.742
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.001    87.889
    50.001    87.887
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.002    87.703
    50.001    87.887
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.908    88.227
    49.906    88.223
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.994    88.215
    49.906    88.223
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.900    88.129
    49.901    88.129
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.876    87.483
    49.901    88.129
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.210    87.674
    50.210    87.674
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.427    87.623
    50.210    87.674
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.130    87.804
    50.130    87.804
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.323    87.698
    50.130    87.804
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.926    88.180
    49.926    88.182
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.989    88.144
    49.926    88.182
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.174    87.536
    50.176    87.541
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.111    87.349
    50.176    87.541
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.201    87.651
    50.201    87.649
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.244    87.670
    50.201    87.649
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.776    87.946
    49.776    87.944
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.711    87.573
    49.776    87.944
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.159    87.832
    50.160    87.832
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.166    87.572
    50.160    87.832
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.999    87.914
    49.999    87.913
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.929    87.610
    49.999    87.913
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.814    87.977
    49.815    87.977
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.868    87.898
    49.815    87.977
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.140    87.754
    50.140    87.752
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.950    87.559
    50.140    87.752
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.927    88.095
    49.929    88.097
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.067    88.178
    49.929    88.097
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.216    87.558
    50.216    87.562
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.271    87.508
    50.216    87.562
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.112    87.913
    50.111    87.910
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.051    87.810
    50.111    87.910
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.037    87.846
    50.038    87.843
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.077    87.727
    50.038    87.843
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.822    88.289
    49.823    88.288
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.820    88.138
    49.823    88.288
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.867    87.907
    49.867    87.904
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.008    87.884
    49.867    87.904
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.196    87.603
    50.196    87.602
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.265    87.640
    50.196    87.602
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.202    87.570
    50.201    87.572
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.436    87.678
    50.201    87.572
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.128    87.788
    50.127    87.791
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.038    87.394
    50.127    87.791
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.270    87.512
    50.270    87.512
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.178    87.045
    50.270    87.512
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.959    88.085
    49.959    88.084
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.069    87.951
    49.959    88.084
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.232    87.508
    50.230    87.511
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.025    87.075
    50.230    87.511
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.120    87.814
    50.120    87.814
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.343    87.366
    50.120    87.814
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.015    88.100
    50.009    88.085
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.975    87.855
    50.009    88.085
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.018    87.866
    50.018    87.866
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.984    87.509
    50.018    87.866
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.240    87.494
    50.237    87.500
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.394    87.005
    50.237    87.500
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.290    87.475
    50.291    87.475
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.291    87.363
    50.291    87.475
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.057    87.873
    50.058    87.872
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.075    87.779
    50.058    87.872
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.142    87.792
    50.141    87.792
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.210    87.900
    50.141    87.792
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.229    87.576
    50.229    87.576
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.020    86.981
    50.229    87.576
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.973    87.890
    49.973    87.885
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.982    87.558
    49.973    87.885
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.180    87.698
    50.181    87.697
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.001    87.137
    50.181    87.697
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.024    87.902
    50.024    87.902
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.867    87.675
    50.024    87.902
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.187    87.728
    50.186    87.728
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.147    87.682
    50.186    87.728
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.221    87.576
    50.221    87.576
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.146    87.007
    50.221    87.576
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.036    87.903
    50.035    87.901
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.098    87.724
    50.035    87.901
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.241    87.646
    50.241    87.645
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.266    87.490
    50.241    87.645
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.197    87.596
    50.197    87.599
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.213    87.587
    50.197    87.599
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.218    87.512
    50.216    87.514
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.295    87.451
    50.216    87.514
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.832    88.240
    49.832    88.240
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.017    88.158
    49.832    88.240
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.212    87.544
    50.211    87.544
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.140    87.039
    50.211    87.544
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.028    87.868
    50.028    87.867
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.878    87.528
    50.028    87.867
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.155    87.659
    50.156    87.658
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.215    87.656
    50.156    87.658
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.936    88.098
    49.936    88.096
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.917    87.859
    49.936    88.096
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.224    87.648
    50.225    87.644
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.036    87.517
    50.225    87.644
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.919    88.261
    49.919    88.260
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.000    88.418
    49.919    88.260
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.905    88.128
    49.905    88.127
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.097    88.186
    49.905    88.127
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.865    88.290
    49.865    88.289
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.734    88.066
    49.865    88.289
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.234    87.719
    50.235    87.717
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.050    87.584
    50.235    87.717
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.087    87.800
    50.090    87.782
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.157    87.065
    50.090    87.782
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.989    87.914
    49.987    87.903
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.070    87.856
    49.987    87.903
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.835    88.231
    49.836    88.232
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.946    88.246
    49.836    88.232
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.031    87.859
    50.031    87.856
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.243    87.474
    50.031    87.856
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.862    88.273
    49.863    88.272
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.931    88.217
    49.863    88.272
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.289    87.488
    50.290    87.488
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.367    87.478
    50.290    87.488
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.167    87.719
    50.167    87.717
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.227    87.706
    50.167    87.717
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.822    88.205
    49.822    88.206
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.875    87.499
    49.822    88.206
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.932    88.274
    49.932    88.273
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.914    88.055
    49.932    88.273
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.150    87.772
    50.149    87.768
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.067    87.490
    50.149    87.768
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.043    87.993
    50.043    87.991
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.083    87.856
    50.043    87.991
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.872    88.165
    49.873    88.165
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.978    88.127
    49.873    88.165
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.877    88.264
    49.876    88.262
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.933    88.235
    49.876    88.262
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.033    87.890
    50.033    87.884
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.085    87.822
    50.033    87.884
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.924    87.901
    49.919    87.924
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.025    87.601
    49.919    87.924
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.261    87.503
    50.261    87.504
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.411    87.350
    50.261    87.504
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.259    87.570
    50.259    87.568
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.153    87.351
    50.259    87.568
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.885    87.722
    49.885    87.721
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.885    87.546
    49.885    87.721
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.139    87.911
    50.139    87.909
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.135    87.871
    50.139    87.909
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.671    87.421
    49.671    87.418
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.774    87.187
    49.671    87.418
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.126    87.864
    50.126    87.862
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.058    87.576
    50.126    87.862
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.069    87.860
    50.069    87.859
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.978    87.583
    50.069    87.859
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.123    87.907
    50.123    87.905
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.980    87.709
    50.123    87.905
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.182    87.650
    50.182    87.649
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.188    87.614
    50.182    87.649
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.174    87.732
    50.174    87.731
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.182    87.670
    50.174    87.731
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.022    87.708
    50.022    87.707
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.008    87.439
    50.022    87.707
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.099    87.640
    50.101    87.636
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.089    87.716
    50.101    87.636
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.907    88.129
    49.907    88.127
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.927    88.167
    49.907    88.127
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.921    88.059
    49.921    88.058
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.832    87.520
    49.921    88.058
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.008    87.892
    50.008    87.889
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.981    87.582
    50.008    87.889
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.923    88.097
    49.922    88.093
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.852    87.878
    49.922    88.093
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.108    87.733
    50.109    87.733
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.292    87.182
    50.109    87.733
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.927    88.263
    49.927    88.264
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.952    87.704
    49.927    88.264
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.136    87.864
    50.136    87.863
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.053    87.586
    50.136    87.863
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.863    88.135
    49.863    88.135
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.921    87.818
    49.863    88.135
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.861    88.203
    49.861    88.202
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.882    88.166
    49.861    88.202
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.814    87.854
    49.816    87.846
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.889    86.949
    49.816    87.846
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.942    88.021
    49.942    88.020
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.910    87.741
    49.942    88.020
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.320    87.456
    50.320    87.456
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.206    86.964
    50.320    87.456
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.848    88.270
    49.848    88.269
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.857    88.164
    49.848    88.269
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.960    87.945
    49.960    87.944
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.818    87.810
    49.960    87.944
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.717    87.717
    49.717    87.717
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.788    87.644
    49.717    87.717
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.154    87.278
    50.154    87.278
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.171    87.207
    50.154    87.278
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.942    89.019
    49.943    89.019
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.084    88.816
    49.943    89.019
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.207    87.505
    50.206    87.508
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.082    86.954
    50.206    87.508
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.847    88.278
    49.847    88.277
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.986    88.290
    49.847    88.277
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.970    87.850
    49.970    87.845
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.940    87.510
    49.970    87.845
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.260    87.518
    50.259    87.520
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.366    87.434
    50.259    87.520
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.706    87.765
    49.707    87.765
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.775    87.733
    49.707    87.765
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.926    88.223
    49.926    88.223
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.807    87.995
    49.926    88.223
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.183    87.628
    50.184    87.625
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.442    87.549
    50.184    87.625
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.084    87.866
    50.084    87.865
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.906    87.763
    50.084    87.865
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.017    87.878
    50.029    87.814
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.131    87.630
    50.029    87.814
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.035    87.548
    50.036    87.549
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.981    87.447
    50.036    87.549
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.002    88.033
    50.002    88.032
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.147    88.065
    50.002    88.032
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.050    87.624
    50.049    87.622
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.109    87.562
    50.049    87.622
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.896    88.336
    49.896    88.336
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.994    88.259
    49.896    88.336
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.902    87.655
    49.902    87.654
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.851    87.499
    49.902    87.654
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.123    87.516
    50.126    87.515
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.939    87.317
    50.126    87.515
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.852    88.281
    49.852    88.280
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.796    88.122
    49.852    88.280
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.273    87.524
    50.274    87.526
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.332    87.430
    50.274    87.526
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.284    87.536
    50.284    87.536
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.352    87.508
    50.284    87.536
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.285    87.512
    50.281    87.514
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.156    87.417
    50.281    87.514
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.859    88.183
    49.859    88.181
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.951    88.192
    49.859    88.181
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.286    87.527
    50.286    87.527
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.402    87.442
    50.286    87.527
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.723    87.989
    49.723    87.989
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.892    87.934
    49.723    87.989
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.050    87.788
    50.050    87.780
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.892    87.636
    50.050    87.780
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.094    87.849
    50.094    87.846
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.276    87.698
    50.094    87.846
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.053    87.548
    50.054    87.545
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.100    87.520
    50.054    87.545
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.066    87.901
    50.067    87.896
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.073    87.730
    50.067    87.896
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.992    88.398
    49.994    88.387
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.998    88.264
    49.994    88.387
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.940    88.271
    49.939    88.272
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.031    88.197
    49.939    88.272
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.861    88.244
    49.861    88.243
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.908    88.256
    49.861    88.243
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.137    87.800
    50.131    87.792
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.220    87.830
    50.131    87.792
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.163    87.469
    50.162    87.470
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.277    87.522
    50.162    87.470
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.973    88.013
    49.973    88.016
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.057    88.059
    49.973    88.016
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.133    87.512
    50.134    87.512
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.337    87.468
    50.134    87.512
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.224    87.716
    50.224    87.715
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.166    87.521
    50.224    87.715
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.038    87.570
    50.039    87.568
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.172    87.443
    50.039    87.568
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.053    87.908
    50.052    87.905
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.120    87.991
    50.052    87.905
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.035    87.968
    50.035    87.967
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.080    87.945
    50.035    87.967
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.849    87.966
    49.849    87.964
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.957    87.948
    49.849    87.964
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.928    88.086
    49.928    88.084
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.811    87.834
    49.928    88.084
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.700    87.823
    49.700    87.821
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.683    87.647
    49.700    87.821
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.976    87.943
    49.975    87.944
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.093    87.922
    49.975    87.944
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.571    87.145
    50.571    87.142
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.689    87.060
    50.571    87.142
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.093    87.914
    50.093    87.913
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.118    87.845
    50.093    87.913
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.857    88.082
    49.857    88.081
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.016    87.871
    49.857    88.081
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.877    87.849
    49.877    87.849
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.093    87.955
    49.877    87.849
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.043    87.867
    50.043    87.868
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.071    87.871
    50.043    87.868
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.821    88.231
    49.821    88.233
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.924    88.012
    49.821    88.233
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.185    87.665
    50.185    87.664
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.228    87.632
    50.185    87.664
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.295    87.512
    50.294    87.513
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.428    87.530
    50.294    87.513
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.549    87.324
    50.551    87.321
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.430    87.180
    50.551    87.321
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.985    87.899
    49.985    87.898
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.131    87.967
    49.985    87.898
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.295    88.288
    50.301    88.292
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.472    88.101
    50.301    88.292
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.537    87.409
    50.533    87.402
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.677    87.293
    50.533    87.402
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.342    87.469
    50.343    87.469
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.483    87.449
    50.343    87.469
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.052    87.836
    50.039    87.887
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.124    87.950
    50.039    87.887
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.017    87.509
    50.018    87.504
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.139    87.510
    50.018    87.504
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.750    86.929
    50.752    86.929
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.780    86.970
    50.752    86.929
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.110    87.481
    50.108    87.484
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.219    87.338
    50.108    87.484
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.879    87.126
    49.878    87.126
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.952    87.137
    49.878    87.126
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.864    88.305
    49.869    88.312
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.994    88.334
    49.869    88.312
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.152    88.644
    50.156    88.641
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.269    88.682
    50.156    88.641
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.257    87.521
    50.257    87.519
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.297    87.501
    50.257    87.519
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.132    87.829
    50.132    87.825
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.249    87.618
    50.132    87.825
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.297    87.611
    50.295    87.611
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.367    87.638
    50.295    87.611
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.992    87.378
    49.992    87.379
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.067    87.517
    49.992    87.379
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.830    88.275
    49.830    88.272
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.047    88.340
    49.830    88.272
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.837    88.315
    49.835    88.311
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.001    88.258
    49.835    88.311
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.149    87.617
    50.149    87.617
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.296    87.657
    50.149    87.617
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.962    88.850
    49.961    88.849
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.043    88.849
    49.961    88.849
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.151    87.713
    50.151    87.711
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.366    87.743
    50.151    87.711
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.559    87.341
    50.558    87.340
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.632    87.350
    50.558    87.340
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.994    87.351
    49.994    87.349
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.978    87.284
    49.994    87.349
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.132    87.796
    50.132    87.795
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.164    87.733
    50.132    87.795
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.220    87.545
    50.219    87.547
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.323    87.453
    50.219    87.547
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.346    87.718
    50.345    87.719
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.476    87.582
    50.345    87.719
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.792    88.219
    49.793    88.218
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.826    88.197
    49.793    88.218
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.032    87.692
    50.032    87.688
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.074    87.767
    50.032    87.688
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.252    87.585
    50.253    87.582
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.230    87.523
    50.253    87.582
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.144    87.774
    50.144    87.763
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.266    87.641
    50.144    87.763
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.184    87.777
    50.184    87.783
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.346    87.860
    50.184    87.783
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.050    87.545
    50.051    87.542
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.120    87.536
    50.051    87.542
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.700    87.118
    50.699    87.116
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.704    87.059
    50.699    87.116
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.249    87.473
    50.249    87.472
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.460    87.408
    50.249    87.472
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.238    87.593
    50.236    87.597
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.273    87.525
    50.236    87.597
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.854    88.289
    49.854    88.289
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.978    88.178
    49.854    88.289
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.727    87.872
    49.727    87.870
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.866    87.753
    49.727    87.870
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.111    87.896
    50.111    87.898
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.194    87.902
    50.111    87.898
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.587    87.328
    50.587    87.330
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.646    87.336
    50.587    87.330
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.002    87.956
    50.002    87.957
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.119    88.025
    50.002    87.957
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.550    87.291
    50.550    87.292
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.622    87.358
    50.550    87.292
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.834    88.276
    49.834    88.275
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.912    88.400
    49.834    88.275
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.769    87.649
    49.769    87.648
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.781    87.618
    49.769    87.648
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.794    87.576
    49.793    87.581
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.947    87.499
    49.793    87.581
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.767    87.753
    49.767    87.753
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.819    87.667
    49.767    87.753
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.018    87.897
    50.018    87.897
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.037    87.710
    50.018    87.897
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.210    87.485
    50.210    87.484
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.207    87.504
    50.210    87.484
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.821    88.170
    49.822    88.169
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.836    88.210
    49.822    88.169
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.128    87.885
    50.128    87.885
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.114    88.026
    50.128    87.885
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.578    87.301
    50.577    87.300
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.603    87.324
    50.577    87.300
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.077    87.837
    50.077    87.839
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.168    87.758
    50.077    87.839
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.884    88.589
    50.881    88.591
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.944    88.487
    50.881    88.591
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.148    88.598
    50.148    88.599
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.151    88.563
    50.148    88.599
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.178    87.682
    50.179    87.682
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.241    87.750
    50.179    87.682
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.610    87.420
    50.611    87.419
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.636    87.460
    50.611    87.419
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.298    87.939
    50.297    87.939
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.304    87.934
    50.297    87.939
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.992    87.913
    49.992    87.914
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.006    87.953
    49.992    87.914
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.907    87.711
    49.906    87.712
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.983    87.793
    49.906    87.712
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.895    88.052
    49.896    88.052
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.908    88.053
    49.896    88.052
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.038    87.924
    50.038    87.925
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.045    87.917
    50.038    87.925
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.818    88.217
    49.819    88.217
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.858    88.247
    49.819    88.217
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.137    87.731
    50.137    87.730
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.197    87.794
    50.137    87.730
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.902    88.222
    49.903    88.223
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.053    88.279
    49.903    88.223
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.222    87.592
    50.222    87.591
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.296    87.655
    50.222    87.591
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.850    87.918
    49.850    87.919
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.953    87.970
    49.850    87.919
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.952    87.928
    49.953    87.928
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.965    87.942
    49.953    87.928
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.045    87.887
    50.045    87.888
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.077    87.867
    50.045    87.888
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.315    87.525
    50.314    87.525
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.412    87.606
    50.314    87.525
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.827    88.196
    49.828    88.195
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.931    88.228
    49.828    88.195
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.118    87.733
    50.118    87.734
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.156    87.736
    50.118    87.734
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.119    87.722
    50.119    87.722
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.112    87.755
    50.119    87.722
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.138    87.654
    50.138    87.652
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.181    87.590
    50.138    87.652
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.797    87.716
    49.798    87.716
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.847    87.768
    49.798    87.716
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.020    87.425
    50.020    87.425
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.025    87.551
    50.020    87.425
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.064    87.812
    50.064    87.814
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.181    87.904
    50.064    87.814
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.819    87.376
    49.819    87.377
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.864    87.337
    49.819    87.377
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.793    87.965
    49.793    87.965
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.887    87.892
    49.793    87.965
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.116    87.756
    50.116    87.755
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.165    87.813
    50.116    87.755
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.493    87.429
    50.493    87.430
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.552    87.479
    50.493    87.430
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.253    86.740
    49.254    86.743
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.350    86.829
    49.254    86.743
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.565    87.342
    50.565    87.342
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.595    87.351
    50.565    87.342
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.042    88.395
    50.042    88.394
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.079    88.353
    50.042    88.394
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.011    87.664
    50.011    87.664
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.102    87.708
    50.011    87.664
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.883    88.110
    49.883    88.109
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.969    88.155
    49.883    88.109
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.136    87.668
    50.136    87.668
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.244    87.798
    50.136    87.668
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.755    87.704
    49.755    87.703
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.836    87.719
    49.755    87.703
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.305    88.068
    50.305    88.067
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.395    88.104
    50.305    88.067
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.870    87.072
    49.870    87.072
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.941    87.106
    49.870    87.072
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.344    88.432
    49.344    88.433
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.481    88.493
    49.344    88.433
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.184    87.917
    50.204    87.927
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.213    88.001
    50.204    87.927
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.122    87.710
    50.121    87.711
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.210    87.779
    50.121    87.711
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.831    87.656
    49.831    87.656
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.951    87.617
    49.831    87.656
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.798    87.659
    49.800    87.658
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.834    87.622
    49.800    87.658
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.800    87.733
    49.801    87.732
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.884    87.807
    49.801    87.732
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.161    87.718
    50.162    87.718
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.196    87.717
    50.162    87.718
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.027    87.885
    50.025    87.885
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.077    87.862
    50.025    87.885
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.167    87.690
    50.168    87.690
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.186    87.777
    50.168    87.690
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.958    88.006
    49.959    88.006
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.034    88.055
    49.959    88.006
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.093    87.864
    50.093    87.865
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.143    87.956
    50.093    87.865
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.584    87.341
    50.583    87.341
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.641    87.360
    50.583    87.341
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.535    87.450
    50.536    87.450
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.596    87.387
    50.536    87.450
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.071    87.895
    50.071    87.896
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.153    87.919
    50.071    87.896
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.102    88.815
    50.104    88.814
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.201    88.838
    50.104    88.814
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.129    87.782
    50.129    87.783
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.157    87.806
    50.129    87.783
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.995    87.908
    49.994    87.907
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.002    87.915
    49.994    87.907
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.214    88.508
    50.213    88.508
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.271    88.659
    50.213    88.508
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.476    87.460
    50.477    87.460
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.521    87.581
    50.477    87.460
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.810    87.894
    49.809    87.895
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.992    87.483
    49.809    87.895
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.118    87.767
    50.118    87.768
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.157    87.863
    50.118    87.768
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.686    88.281
    50.686    88.281
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.734    88.235
    50.686    88.281
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.126    88.138
    50.125    88.138
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.237    88.225
    50.125    88.138
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.467    87.435
    50.467    87.434
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.527    87.400
    50.467    87.434
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.204    87.579
    50.205    87.580
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.295    87.483
    50.205    87.580
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.991    88.073
    49.990    88.074
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.130    88.153
    49.990    88.074
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.131    87.820
    50.134    87.822
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.223    87.938
    50.134    87.822
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.012    87.496
    50.012    87.497
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.090    87.514
    50.012    87.497
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.256    87.585
    50.256    87.586
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.377    87.572
    50.256    87.586
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.991    87.750
    49.989    87.751
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.051    87.808
    49.989    87.751
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.875    88.099
    49.875    88.100
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.869    88.024
    49.875    88.100
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.844    88.088
    49.844    88.088
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.875    88.131
    49.844    88.088
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.210    87.619
    50.209    87.617
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.218    87.695
    50.209    87.617
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.515    87.379
    50.514    87.378
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.626    87.418
    50.514    87.378
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.204    87.622
    50.204    87.622
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.201    87.750
    50.204    87.622
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.002    87.933
    50.001    87.933
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.018    87.993
    50.001    87.933
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.005    87.910
    50.006    87.908
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.033    87.863
    50.006    87.908
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.288    88.120
    50.288    88.121
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.257    88.208
    50.288    88.121
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.164    88.607
    50.170    88.615
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.296    88.586
    50.170    88.615
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.589    87.359
    49.590    87.359
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.687    87.278
    49.590    87.359
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.075    87.743
    50.075    87.743
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.200    87.758
    50.075    87.743
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.285    87.926
    50.284    87.917
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.347    87.896
    50.284    87.917
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.303    87.886
    50.300    87.876
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.261    87.895
    50.300    87.876
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.109    87.600
    50.110    87.601
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.134    87.669
    50.110    87.601
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.263    87.784
    50.263    87.783
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.292    87.658
    50.263    87.783
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.813    88.102
    49.810    88.105
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.959    88.105
    49.810    88.105
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.092    87.785
    50.091    87.787
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.122    87.893
    50.091    87.787
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.882    88.023
    49.883    88.021
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.922    87.909
    49.883    88.021
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.477    87.478
    50.478    87.479
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.498    87.439
    50.478    87.479
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.041    87.785
    50.040    87.786
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.104    87.772
    50.040    87.786
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.845    88.167
    49.845    88.162
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.886    88.104
    49.845    88.162
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.785    86.792
    49.786    86.792
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.752    86.852
    49.786    86.792
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.062    87.716
    50.061    87.716
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.164    87.795
    50.061    87.716
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.147    87.791
    50.147    87.790
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.231    87.832
    50.147    87.790
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.105    87.826
    50.105    87.825
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.162    87.910
    50.105    87.825
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.024    87.983
    50.023    87.983
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.083    87.991
    50.023    87.983
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.995    88.831
    49.994    88.831
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.049    88.889
    49.994    88.831
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.163    87.775
    50.164    87.774
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.212    87.860
    50.164    87.774
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.253    88.283
    50.251    88.281
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.312    88.318
    50.251    88.281
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.077    87.895
    50.077    87.896
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.121    87.959
    50.077    87.896
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.853    88.789
    49.856    88.796
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.890    88.692
    49.856    88.796
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.017    87.879
    50.017    87.878
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.046    87.911
    50.017    87.878
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.013    87.880
    50.013    87.880
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.042    87.873
    50.013    87.880
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.018    87.876
    50.018    87.876
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.035    87.910
    50.018    87.876
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.158    87.672
    50.158    87.671
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.217    87.725
    50.158    87.671
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.838    88.261
    49.838    88.260
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.894    88.237
    49.838    88.260
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.992    88.850
    49.993    88.849
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.066    88.809
    49.993    88.849
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.514    87.387
    50.514    87.387
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.510    87.365
    50.514    87.387
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.073    87.814
    50.073    87.813
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.120    87.840
    50.073    87.813
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.854    88.149
    49.854    88.149
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.863    88.198
    49.854    88.149
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.326    87.793
    50.326    87.794
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.411    87.813
    50.326    87.794
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.870    86.711
    50.869    86.711
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.926    86.808
    50.869    86.711
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.123    87.789
    50.124    87.789
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.123    87.816
    50.124    87.789
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.200    87.922
    50.200    87.922
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.242    87.936
    50.200    87.922
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.068    87.731
    50.068    87.733
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.145    87.792
    50.068    87.733
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.816    88.218
    49.817    88.218
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.913    88.134
    49.817    88.218
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.699    88.333
    50.699    88.334
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.731    88.351
    50.699    88.334
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.904    88.100
    49.904    88.100
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.952    88.048
    49.904    88.100
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.017    87.619
    50.018    87.619
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.082    87.653
    50.018    87.619
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.973    88.128
    49.973    88.130
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.964    88.056
    49.973    88.130
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.591    87.338
    50.590    87.336
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.618    87.344
    50.590    87.336
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.722    87.095
    49.723    87.095
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.783    87.121
    49.723    87.095
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.002    87.883
    50.002    87.883
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.066    87.870
    50.002    87.883
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.843    87.792
    49.843    87.792
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.946    87.810
    49.843    87.792
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.917    88.186
    49.920    88.187
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.955    88.149
    49.920    88.187
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.543    87.426
    50.543    87.426
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.582    87.528
    50.543    87.426
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.099    87.429
    50.100    87.429
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.111    87.373
    50.100    87.429
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.914    88.159
    49.914    88.163
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.982    88.233
    49.914    88.163
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.552    87.418
    50.551    87.417
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.577    87.369
    50.551    87.417
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.531    87.440
    50.531    87.439
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.588    87.472
    50.531    87.439
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.538    87.413
    50.537    87.413
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.529    87.393
    50.537    87.413
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.510    87.467
    50.509    87.465
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.575    87.483
    50.509    87.465
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.538    87.426
    50.537    87.426
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.599    87.472
    50.537    87.426
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.525    87.468
    50.526    87.467
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.509    87.468
    50.526    87.467
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.538    87.461
    50.538    87.460
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.603    87.537
    50.538    87.460
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.528    87.438
    50.529    87.438
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.569    87.518
    50.529    87.438
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.837    88.192
    49.837    88.193
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.950    88.138
    49.837    88.193
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.536    87.434
    50.536    87.434
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.581    87.428
    50.536    87.434
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.524    87.447
    50.528    87.440
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.565    87.544
    50.528    87.440
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.514    87.479
    50.516    87.477
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.549    87.565
    50.516    87.477
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.537    87.434
    50.537    87.433
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.588    87.429
    50.537    87.433
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.504    87.461
    50.504    87.460
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.573    87.512
    50.504    87.460
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.880    88.116
    49.880    88.117
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.973    88.027
    49.880    88.117
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.544    87.425
    50.545    87.427
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.602    87.497
    50.545    87.427
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.927    88.134
    49.927    88.134
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.973    88.197
    49.927    88.134
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.542    87.445
    50.542    87.445
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.580    87.460
    50.542    87.445
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.541    87.455
    50.540    87.454
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.599    87.536
    50.540    87.454
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.535    87.465
    50.537    87.464
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.594    87.492
    50.537    87.464
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.145    87.901
    50.145    87.901
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.191    87.942
    50.145    87.901
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.046    88.476
    50.046    88.475
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.225    88.482
    50.046    88.475
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.447    87.287
    50.445    87.285
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.534    87.323
    50.445    87.285
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.558    87.435
    50.556    87.434
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.607    87.432
    50.556    87.434
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.053    88.395
    50.053    88.395
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.147    88.446
    50.053    88.395
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.531    87.412
    50.531    87.412
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.565    87.342
    50.531    87.412
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.526    87.424
    50.526    87.423
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.560    87.440
    50.526    87.423
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.534    87.404
    50.534    87.405
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.608    87.433
    50.534    87.405
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.518    87.434
    50.519    87.433
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.538    87.415
    50.519    87.433
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.894    86.982
    50.892    86.981
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.925    86.981
    50.892    86.981
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.514    87.440
    50.515    87.438
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.600    87.470
    50.515    87.438
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.538    87.453
    50.537    87.454
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.585    87.463
    50.537    87.454
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.528    87.423
    50.527    87.421
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.577    87.496
    50.527    87.421
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.530    87.416
    50.533    87.418
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.613    87.184
    50.533    87.418
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.171    87.661
    50.171    87.663
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.171    87.691
    50.171    87.663
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.797    86.820
    49.798    86.818
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.765    86.903
    49.798    86.818
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.701    88.297
    50.699    88.299
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.721    88.283
    50.699    88.299
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.098    87.696
    50.098    87.695
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.222    87.739
    50.098    87.695
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.801    86.808
    49.801    86.808
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.817    86.996
    49.801    86.808
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.702    87.440
    49.702    87.438
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.784    87.507
    49.702    87.438
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.012    87.902
    50.012    87.902
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.090    87.906
    50.012    87.902
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.140    87.655
    50.140    87.656
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.190    87.687
    50.140    87.656
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.254    88.136
    49.254    88.135
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.373    88.183
    49.254    88.135
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.556    87.433
    50.556    87.432
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.701    87.534
    50.556    87.432
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.044    87.892
    50.044    87.892
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.019    87.904
    50.044    87.892
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.048    87.898
    50.047    87.898
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.084    87.862
    50.047    87.898
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.046    87.895
    50.046    87.894
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.192    87.869
    50.046    87.894
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.209    87.859
    50.209    87.859
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.282    87.924
    50.209    87.859
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.823    88.492
    49.824    88.490
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.859    88.627
    49.824    88.490
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.024    87.612
    50.025    87.607
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.063    87.652
    50.025    87.607
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.849    88.157
    49.850    88.157
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.962    88.123
    49.850    88.157
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.844    88.222
    49.845    88.223
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.978    88.261
    49.845    88.223
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.519    87.450
    50.520    87.450
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.543    87.443
    50.520    87.450
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.009    88.385
    50.010    88.383
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.107    87.950
    50.010    88.383
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.339    87.857
    50.339    87.857
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.382    87.863
    50.339    87.857
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.081    87.767
    50.081    87.768
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.138    87.793
    50.081    87.768
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.568    87.365
    50.568    87.364
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.605    87.319
    50.568    87.364
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.135    87.802
    50.134    87.802
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.185    87.865
    50.134    87.802
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.185    87.559
    50.186    87.559
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.349    87.343
    50.186    87.559
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.032    87.887
    50.033    87.888
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.133    87.598
    50.033    87.888
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.044    87.891
    50.045    87.891
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.125    88.048
    50.045    87.891
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.706    89.574
    49.708    89.573
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.818    88.889
    49.708    89.573
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.040    87.901
    50.039    87.902
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.147    87.746
    50.039    87.902
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.955    88.761
    49.957    88.763
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.037    88.789
    49.957    88.763
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    50.683    87.227
    50.682    87.227
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    50.711    86.844
    50.682    87.227
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.542    87.785
    49.543    87.787
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.496    87.360
    49.543    87.787
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    49.647    89.094
    49.648    89.095
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    49.747    88.870
    49.648    89.095
END

# Confidence ellipses for relative location
gmt psxy -: -R $projection -SE -Wthick -O -K << END >> $psfile
    50.329    87.685   -76.050     2.402     4.204
    50.297    87.633   -81.733     3.003     5.525
    50.238    87.842   -75.176     3.163     5.960
    50.019    87.568   -85.282     2.517     3.359
    50.229    88.508    83.290     7.215    12.397
    50.025    87.858    88.333     1.282     1.516
    49.938    88.146    72.859     3.065     3.160
    50.049    87.888    55.413     1.365     1.623
    50.048    87.873     5.119     3.626     3.836
    50.082    87.878    64.054     1.767     1.980
    49.909    88.136   -51.008     2.697     2.787
    50.099    87.769    82.581     1.092     1.288
    50.045    87.851    49.008     1.404     1.560
    50.011    87.958    83.805     1.975     4.090
    49.900    88.144    10.691     4.451     4.790
    50.078    87.793    58.904     2.915     3.655
    49.985    88.203    12.881     3.404     3.619
    49.941    88.123    -0.781     3.221     4.244
    50.032    87.660    50.927     2.614     3.480
    50.007    87.889    68.014     1.647     2.117
    50.047    87.819    -0.312     3.479     4.059
    49.953    87.983    34.199     2.574     2.624
    50.163    87.734    84.596     1.051     1.522
    49.981    87.818   -30.120     4.414     5.956
    49.991    88.176    -0.763     3.491     3.971
    50.219    87.779    52.735     2.754     3.168
    50.001    87.855    46.625     2.479     3.129
    50.147    87.722    67.133     1.937     2.393
    50.182    87.627   -22.038     3.517     3.689
    50.218    87.634     6.107     3.913     6.063
    50.153    87.831     7.874     3.221     4.336
    49.986    87.775     1.355     6.418     7.046
    50.182    87.650    27.862     2.522     3.057
    50.176    87.679    20.779     3.275     6.135
    50.147    87.734     4.469     2.144     5.824
    50.086    87.776    26.393     3.857     5.739
    50.157    87.742     5.676     2.713     3.411
    50.001    87.887   -22.216     1.796     3.462
    49.906    88.223   -25.384     2.724     3.677
    49.901    88.129    -5.261     3.543     8.052
    50.210    87.674     4.958     4.254     7.019
    50.130    87.804   -22.941     2.239     3.854
    49.926    88.182   -28.205     3.474     6.298
    50.176    87.541    34.223     2.699     4.974
    50.201    87.649    -5.012     3.088     4.485
    49.776    87.944     4.138     3.849    10.554
    50.160    87.832   -28.974     1.786     3.207
    49.999    87.913   -12.628     2.704     7.475
    49.815    87.977    -6.734     2.855     6.254
    50.140    87.752    -7.174     2.703     5.413
    49.929    88.097   -28.042     2.546     3.762
    50.216    87.562    28.010     2.884     5.095
    50.111    87.910    -3.122     3.330     3.842
    50.038    87.843   -19.685     1.768     3.145
    49.823    88.288   -75.937     1.866     3.137
    49.867    87.904   -12.140     2.376     4.633
    50.196    87.602    13.372     3.447     4.544
    50.201    87.572    29.167     5.589     8.747
    50.127    87.791     1.256     3.614     5.163
    50.270    87.512    62.581     2.944     5.056
    49.959    88.084   -34.106     1.836     3.674
    50.230    87.511    52.230     3.645     6.961
    50.120    87.814    -4.165     2.982     5.518
    50.009    88.085   -35.262     1.757     3.505
    50.018    87.866   -16.145     2.124     4.634
    50.237    87.500    54.242     3.577     7.893
    50.291    87.475    78.513     3.647     6.641
    50.058    87.872   -23.864     1.822     2.302
    50.141    87.792     0.788     3.066     5.090
    50.229    87.576    36.039     3.770     7.394
    49.973    87.885    -4.340     3.798     9.589
    50.181    87.697     7.009     3.885     6.338
    50.024    87.902   -15.152     3.397     7.929
    50.186    87.728    -8.505     3.244     4.757
    50.221    87.576    32.688     3.733     9.302
    50.035    87.901   -21.238     2.103     4.261
    50.241    87.645    -4.509     2.013     2.190
    50.197    87.599    14.918     3.820     5.414
    50.216    87.514    37.101     3.720     7.034
    49.832    88.240   -23.413     3.958     6.519
    50.211    87.544    40.802     3.475     9.501
    50.028    87.867   -10.212     2.208     4.764
    50.156    87.658    -7.964     2.339     2.474
    49.936    88.096   -70.380     1.641     2.550
    50.225    87.644    23.028     5.461     8.521
    49.919    88.260   -49.547     3.408     8.506
    49.905    88.127    -6.091     4.595     7.534
    49.865    88.289   -21.569     3.196     5.758
    50.235    87.717   -12.139     4.607     5.224
    50.090    87.782   -74.188     0.918     4.769
    49.987    87.903   -23.960     1.761     3.596
    49.836    88.232   -24.749     3.322     6.098
    50.031    87.856    -0.260     3.161     6.796
    49.863    88.272   -43.655     1.830     2.792
    50.290    87.488    71.271     3.324     5.575
    50.167    87.717    83.877     1.643     2.608
    49.822    88.206    -9.141     3.697     6.857
    49.932    88.273   -27.223     2.147     4.367
    50.149    87.768     0.258     2.742     4.313
    50.043    87.991   -76.142     1.745     2.940
    49.873    88.165   -23.481     2.255     4.262
    49.876    88.262   -72.869     1.336     2.164
    50.033    87.884   -20.558     1.765     2.968
    49.919    87.924    19.291     6.384    12.448
    50.261    87.504    59.798     3.851     7.708
    50.259    87.568    46.691     3.394     5.226
    49.885    87.721    -2.964     1.532     2.848
    50.139    87.909   -51.277     1.652     1.844
    49.671    87.418    31.310     2.285     7.664
    50.126    87.862   -18.663     2.573     4.223
    50.069    87.859   -15.709     2.206     3.813
    50.123    87.905   -24.895     3.129     5.629
    50.182    87.649    78.563     1.171     1.567
    50.174    87.731    -0.263     2.584     3.535
    50.022    87.707     2.533     1.921     3.993
    50.101    87.636    29.568     3.832     7.869
    49.907    88.127   -20.308     3.044     5.307
    49.921    88.058    -8.282     2.966     6.804
    50.008    87.889    -9.474     2.592     4.853
    49.922    88.093   -20.964     2.918     4.744
    50.109    87.733    24.254     3.499     7.303
    49.927    88.264   -20.328     4.193     6.141
    50.136    87.863    19.363     3.853     4.789
    49.863    88.135    -6.013     2.913     6.024
    49.861    88.202   -22.149     2.935     4.662
    49.816    87.846   -70.295     0.392     3.380
    49.942    88.020    -5.263     2.022     4.737
    50.320    87.456    85.028     2.841     4.245
    49.848    88.269   -31.786     1.921     3.350
    49.960    87.944    -0.682     2.818     4.954
    49.717    87.717     2.550     2.426     5.205
    50.154    87.278    73.940     2.222     2.506
    49.943    89.019   -54.946     5.084     7.194
    50.206    87.508    50.562     2.681     6.541
    49.847    88.277   -34.282     2.080     3.325
    49.970    87.845     6.857     2.607     6.139
    50.259    87.520    44.731     2.840     3.967
    49.707    87.765     6.190     2.162     4.543
    49.926    88.223    18.227     4.769     6.338
    50.184    87.625    31.286     4.132     9.621
    50.084    87.865    16.199     3.480     5.835
    50.029    87.814    23.652     4.248     5.350
    50.036    87.549    32.169     2.795     8.535
    50.002    88.032   -29.543     2.387     4.567
    50.049    87.622    84.405     2.382     2.763
    49.896    88.336   -34.023     2.460     4.549
    49.902    87.654     8.515     3.057     4.206
    50.126    87.515    36.986     2.731     5.457
    49.852    88.280   -23.271     2.730     4.725
    50.274    87.526    58.325     3.000     3.675
    50.284    87.536    63.443     2.744     4.421
    50.281    87.514    63.481     2.897     4.478
    49.859    88.181   -10.080     2.459     5.029
    50.286    87.527    67.111     3.289     5.684
    49.723    87.989   -17.353     2.355     3.659
    50.050    87.780    30.436     4.994     7.708
    50.094    87.846    20.590     3.299     5.830
    50.054    87.545    36.755     4.055     9.465
    50.067    87.896    22.502     4.833     7.429
    49.994    88.387    -1.267     5.564     6.646
    49.939    88.272   -35.862     3.498     5.246
    49.861    88.243   -39.332     2.624     5.524
    50.131    87.792    24.434     4.980     9.195
    50.162    87.470    42.200     3.219     6.383
    49.973    88.016   -31.217     3.137     6.402
    50.134    87.512    28.780     2.909     4.796
    50.224    87.715    17.138     3.966     5.873
    50.039    87.568    29.271     2.327     6.607
    50.052    87.905   -28.377     2.224     4.265
    50.035    87.967   -46.300     1.683     2.399
    49.849    87.964   -10.515     1.808     3.957
    49.928    88.084   -18.242     1.907     3.712
    49.700    87.821    12.330     2.257     7.575
    49.975    87.944    77.416     2.015     4.443
    50.571    87.142    79.309     6.846     7.407
    50.093    87.913   -40.187     2.064     3.158
    49.857    88.081    -8.482     3.135     7.162
    49.877    87.849    10.498     3.263     5.168
    50.043    87.868    12.684     2.758     4.270
    49.821    88.233   -14.318     4.119     7.102
    50.185    87.664    -4.711     2.035     3.855
    50.294    87.513    74.354     1.759     3.419
    50.551    87.321    29.903     4.795     6.367
    49.985    87.898   -21.064     1.778     3.368
    50.301    88.292    68.119     3.266     6.555
    50.533    87.402   -37.499     2.389     5.622
    50.343    87.469   -89.728     2.688     5.041
    50.039    87.887    34.908     6.083     8.480
    50.018    87.504    34.906     4.446     9.763
    50.752    86.929   -32.747     3.677     4.898
    50.108    87.484    38.381     2.208     5.740
    49.878    87.126    46.644     2.073     5.917
    49.869    88.312   -25.910     3.039     4.644
    50.156    88.641    85.425     3.041     6.948
    50.257    87.519    51.666     1.843     3.396
    50.132    87.825    20.100     4.362     8.838
    50.295    87.611    33.776     4.923     7.175
    49.992    87.379    42.076     2.167     7.818
    49.830    88.272   -15.169     3.148     5.662
    49.835    88.311   -16.819     5.044     5.425
    50.149    87.617   -62.992     2.246     2.452
    49.961    88.849   -75.030     1.520     3.890
    50.151    87.711    21.493     3.014     4.811
    50.558    87.340   -44.166     1.870     4.367
    49.994    87.349    34.296     2.095     2.463
    50.132    87.795   -54.703     1.588     2.231
    50.219    87.547    43.506     2.981     5.812
    50.345    87.719    28.091     4.100     6.274
    49.793    88.218   -66.733     1.600     3.245
    50.032    87.688     1.646     1.891     2.401
    50.253    87.582    41.081     1.920     3.262
    50.144    87.763    17.365     2.073     2.635
    50.184    87.783     4.668     4.043     6.436
    50.051    87.542    34.275     2.197     4.508
    50.699    87.116   -42.027     1.593     2.897
    50.249    87.472    36.820     2.633     3.669
    50.236    87.597    40.387     2.909     4.811
    49.854    88.289   -10.804     2.671     4.073
    49.727    87.870    10.230     3.453     7.576
    50.111    87.898   -18.891     2.607     3.978
    50.587    87.330   -30.304     1.274     1.542
    50.002    87.957   -84.028     2.365     3.378
    50.550    87.292   -50.275     2.555     5.802
    49.834    88.275   -28.666     2.038     3.428
    49.769    87.648    64.875     0.995     1.261
    49.793    87.581    14.702     4.326     9.783
    49.767    87.753    32.429     2.261     4.416
    50.018    87.897    23.742     2.868     4.113
    50.210    87.484    34.711     1.908     3.364
    49.822    88.169    35.334     3.481     5.981
    50.128    87.885    -1.995     2.604     5.575
    50.577    87.300   -40.130     1.621     3.787
    50.077    87.839    31.173     2.001     2.671
    50.881    88.591    33.303     1.607     2.154
    50.148    88.599    74.405     2.196     3.882
    50.179    87.682   -41.781     1.316     1.966
    50.611    87.419   -27.037     1.967     2.913
    50.297    87.939   -63.278     1.200     2.149
    49.992    87.914   -63.558     1.222     1.553
    49.906    87.712   -29.741     1.663     1.718
    49.896    88.052   -67.742     1.359     1.814
    50.038    87.925   -70.992     1.259     1.683
    49.819    88.217   -69.334     1.819     2.369
    50.137    87.730     1.977     1.847     4.447
    49.903    88.223    56.446     1.376     2.037
    50.222    87.591   -19.505     1.552     1.966
    49.850    87.919    62.987     1.550     2.090
    49.953    87.928    70.842     1.886     2.265
    50.045    87.888   -73.523     1.551     1.830
    50.314    87.525    11.848     2.289     3.122
    49.828    88.195   -68.137     1.588     2.106
    50.118    87.734   -32.031     1.078     1.363
    50.119    87.722   -41.592     1.061     1.425
    50.138    87.652   -22.900     1.130     1.411
    49.798    87.716    75.751     1.418     1.649
    50.020    87.425    -9.078     1.501     1.949
    50.064    87.814   -51.066     1.158     1.671
    49.819    87.377    -3.420     1.783     1.865
    49.793    87.965    43.749     1.439     1.855
    50.116    87.755   -45.135     1.567     2.023
    50.493    87.430   -38.102     1.862     2.493
    49.254    86.743    60.635     2.824     3.902
    50.565    87.342   -47.314     2.533     3.304
    50.042    88.394    65.510     2.358     3.346
    50.011    87.664    12.839     1.900     2.155
    49.883    88.109    64.758     1.671     2.470
    50.136    87.668   -24.406     1.624     1.981
    49.755    87.703    43.847     1.498     2.167
    50.305    88.067   -67.671     1.420     2.224
    49.870    87.072    57.027     1.689     1.808
    49.344    88.433    68.629     3.220     5.444
    50.204    87.927   -67.091     3.117     5.936
    50.121    87.711   -68.932     1.792     1.961
    49.831    87.656    34.978     1.679     2.435
    49.800    87.658    43.742     1.291     1.805
    49.801    87.732    53.902     1.539     2.777
    50.162    87.718   -65.446     1.719     2.015
    50.025    87.885    73.586     1.542     2.129
    50.168    87.690   -50.878     1.621     1.908
    49.959    88.006    65.656     1.821     3.168
    50.093    87.865   -66.298     1.522     1.754
    50.583    87.341   -21.157     1.640     2.626
    50.536    87.450   -20.448     1.691     2.505
    50.071    87.896    86.315     2.157     2.833
    50.104    88.814    44.001     3.643     5.805
    50.129    87.783   -49.388     2.270     3.102
    49.994    87.907    80.776     1.745     1.949
    50.213    88.508    -9.154     2.845     3.520
    50.477    87.460   -24.017     2.696     3.726
    49.809    87.895    54.062     2.217     3.004
    50.118    87.768   -39.410     1.439     1.737
    50.686    88.281     0.829     2.743     3.542
    50.125    88.138   -71.357     1.641     2.692
    50.467    87.434   -36.808     2.400     4.120
    50.205    87.580   -62.617     1.853     2.332
    49.990    88.074     6.062     2.158     3.582
    50.134    87.822   -67.705     2.084     4.639
    50.012    87.497    26.106     2.146     2.653
    50.256    87.586   -65.235     2.089     3.116
    49.989    87.751    53.899     2.199     2.580
    49.875    88.100    39.612     1.308     1.411
    49.844    88.088   -70.283     1.815     2.351
    50.209    87.617   -49.075     1.442     1.940
    50.514    87.378   -20.552     1.887     3.128
    50.204    87.622   -49.349     1.641     2.078
    50.001    87.933    71.684     1.841     2.676
    50.006    87.908    65.739     2.041     2.965
    50.288    88.121   -51.539     2.565     3.520
    50.170    88.615    22.187     4.035     7.295
    49.590    87.359    46.293     3.839     5.585
    50.075    87.743   -12.957     1.681     1.867
    50.284    87.917     8.437     2.617     4.194
    50.300    87.876    12.789     2.783     6.281
    50.110    87.601    12.171     1.519     4.971
    50.263    87.783     5.015     2.348     6.611
    49.810    88.105    21.852     3.804     7.765
    50.091    87.787    14.517     2.721     7.754
    49.883    88.021    14.746     2.889     6.240
    50.478    87.479   -14.698     2.018     4.485
    50.040    87.786     7.986     2.269     6.406
    49.845    88.162    15.155     3.589     6.833
    49.786    86.792   -78.562     3.286     3.605
    50.061    87.716     7.486     1.817     7.251
    50.147    87.790   -46.197     1.000     1.583
    50.105    87.825   -48.020     1.087     1.793
    50.023    87.983   -58.266     1.501     2.205
    49.994    88.831     1.184     2.901     4.208
    50.164    87.774   -46.191     1.009     1.655
    50.251    88.281   -41.433     2.081     3.537
    50.077    87.896   -61.414     1.655     1.911
    49.856    88.796    14.174     4.182     4.502
    50.017    87.878   -64.966     1.315     1.415
    50.013    87.880   -76.380     1.614     1.835
    50.018    87.876   -69.041     1.960     2.314
    50.158    87.671   -32.456     1.965     2.725
    49.838    88.260    51.325     2.479     3.724
    49.993    88.849   -87.845     1.409     1.929
    50.514    87.387   -39.324     1.804     3.380
    50.073    87.813   -52.562     1.920     2.430
    49.854    88.149    48.755     1.768     2.845
    50.326    87.794   -69.014     1.230     1.855
    50.869    86.711   -21.394     2.781     4.321
    50.124    87.789   -69.477     2.022     2.527
    50.200    87.922   -66.140     1.329     1.948
    50.068    87.733   -29.452     2.020     2.223
    49.817    88.218    57.689     2.278     3.494
    50.699    88.334    25.385     1.909     2.485
    49.904    88.100    31.511     1.307     1.787
    50.018    87.619     0.121     1.423     1.826
    49.973    88.130    61.672     1.994     2.559
    50.590    87.336   -33.579     2.429     4.699
    49.723    87.095    88.721     2.671     2.890
    50.002    87.883   -82.667     1.947     2.165
    49.843    87.792    44.478     1.356     1.791
    49.920    88.187    39.965     1.775     2.220
    50.543    87.426   -20.642     1.340     2.421
    50.100    87.429    -4.176     1.545     1.790
    49.914    88.163    20.027     3.580     5.963
    50.551    87.417   -28.869     0.905     1.570
    50.531    87.439   -21.289     1.539     2.616
    50.537    87.413   -30.935     1.249     2.120
    50.509    87.465   -16.866     1.552     2.859
    50.537    87.426   -20.802     1.312     2.566
    50.526    87.467   -23.349     1.342     2.038
    50.538    87.460   -19.092     1.071     2.192
    50.529    87.438   -24.062     1.456     2.524
    49.837    88.193    51.279     2.151     3.227
    50.536    87.434   -32.825     1.239     1.817
    50.528    87.440   -19.636     1.596     3.168
    50.516    87.477   -16.166     1.803     3.125
    50.537    87.433   -22.453     1.029     1.973
    50.504    87.460   -16.969     1.656     3.204
    49.880    88.117    58.833     2.108     2.992
    50.545    87.427   -12.788     1.604     3.570
    49.927    88.134    50.168     1.190     1.761
    50.542    87.445   -23.724     1.607     2.328
    50.540    87.454   -19.587     1.510     2.716
    50.537    87.464   -13.396     1.331     2.589
    50.145    87.901   -66.926     1.471     2.517
    50.046    88.475    78.254     3.111     4.906
    50.445    87.285   -55.000     1.841     3.522
    50.556    87.434   -22.283     1.130     2.146
    50.053    88.395    50.793     2.517     3.016
    50.531    87.412   -17.514     1.305     2.364
    50.526    87.423   -25.732     1.253     1.976
    50.534    87.405   -26.697     1.557     2.770
    50.519    87.433   -26.386     1.485     2.482
    50.892    86.981   -26.374     1.177     2.192
    50.515    87.438   -24.702     1.451     3.078
    50.537    87.454   -23.251     1.328     2.825
    50.527    87.421   -16.470     1.008     1.698
    50.533    87.418   -16.932     1.273     2.482
    50.171    87.663     5.732     1.956     4.181
    49.798    86.818    73.414     1.516     2.131
    50.699    88.299     7.062     1.419     2.657
    50.098    87.695   -32.511     1.287     1.734
    49.801    86.808    71.407     2.128     2.591
    49.702    87.438    26.283     2.060     3.865
    50.012    87.902   -81.254     1.509     1.757
    50.140    87.656   -32.134     1.356     1.662
    49.254    88.135    27.444     2.244     3.339
    50.556    87.432   -27.955     1.533     2.460
    50.044    87.892   -70.510     1.414     1.846
    50.047    87.898   -81.834     1.365     1.756
    50.046    87.894   -69.696     1.604     2.066
    50.209    87.859   -59.384     1.275     2.005
    49.824    88.490    40.987     3.553     4.664
    50.025    87.607    12.066     1.596     4.680
    49.850    88.157    19.794     2.393     3.716
    49.845    88.223    48.690     2.081     3.108
    50.520    87.450   -35.574     1.515     2.288
    50.010    88.383    16.734     2.924     3.873
    50.339    87.857   -71.525     1.266     1.795
    50.081    87.768   -50.031     1.175     1.417
    50.568    87.364   -22.190     1.781     3.338
    50.134    87.802   -53.040     1.276     1.618
    50.186    87.559    -9.329     1.576     1.881
    50.033    87.888   -82.098     1.591     1.813
    50.045    87.891   -78.260     1.349     1.563
    49.708    89.573    68.819     2.808     4.381
    50.039    87.902    82.978     1.603     2.024
    49.957    88.763    69.858     2.305     3.177
    50.682    87.227   -37.011     1.730     3.246
    49.543    87.787    67.727     2.466     3.340
    49.648    89.095    69.812     2.099     2.644
END

# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
    50.025    87.858     0.300
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
    50.099    87.769     0.200
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
    50.163    87.734     0.200
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# Hypocentroid confidence ellipse
gmt psxy -: -R $projection -SE -Wthick,blue -O -K << END >> $psfile
    49.207    86.693   -88.717     1.114     1.159
END
gmt pstext -: -R $projection -F+f6p,Helvetica,blue+a0.+jBL -O -K << END >> $psfile
    49.207    86.716   Hypocentroid
END

# Circle of radius 5 km for reference
gmt psxy -: -R $projection -SE -Wthick,red -O -K << END >> $psfile
    49.207    86.693     0.000    10.000    10.000
END
gmt psxy -: -R $projection -Sx -Wthinnest,blue -O -K << END >> $psfile
    49.207    86.693     0.070
END
gmt pstext -: -R $projection -F+f6p,Helvetica-Bold,red+a0.+jBC -Gwhite -O << END >> $psfile
    49.162    86.693   5 km
END
